#rm(list=ls())
library(lme4);library(lmerTest)
library(nlme);library(piecewiseSEM)
library(boot);library(Rfit)
library(MuMIn);library(ggplot2)
library(grid);library(gridExtra)
library(gtable);library(plyr)
library(dplyr);library(data.table)
library(MuMIn);options(na.action = "na.fail")
library(glmnet);library(glmnetUtils)
library(SoDA);library(spdep)

setwd("C:/Users/masum/Google Drive/Chapter_IV/GEB_REVISION/Store in Figshare")
can<-fread("Hisano_and_Chen_GEB.csv")

#Centering all the explanatory variables
can[,":="(SA=scale(SA1),
          logSA1=log(SA1),
          CMIave=scale(CMIave1),
          AIave=scale(AIave1),
          MATave=scale(MATave1))] %>% 
  .[,":="(lognbsp1=log(Spnbsp1),
          sqrtnbsp1=sqrt(Spnbsp1),
          logFDis1=log(SpFDis1+1),
          sqrtFDis1=sqrt(SpFDis1),
          logPC11=log(SpPC11+abs(min(SpPC11))+1),
          sqrtPC11=sqrt(SpPC11+abs(min(SpPC11))))] %>% 
  .[,":="(logSA=scale(logSA1),
          Spnbsp=scale(Spnbsp1),
          lognbsp=scale(lognbsp1),
          sqrtnbsp=scale(sqrtnbsp1),
          SpFDis=scale(SpFDis1),
          logFDis=scale(logFDis1),
          sqrtFDis=scale(sqrtFDis1),
          SpPC1=scale(SpPC11),
          logPC1=scale(logPC11),
          sqrtPC1=scale(sqrtPC11))] %>% 
  .[,":="(PS1=PS)] %>% 
  .[,":="(PS=scale(PS1),logPS=scale(log(PS1)),sqrtPS=scale(sqrt(PS1)))]

ci.fun<-function(mod,coeff){
  frame<-mod@frame
  x<-frame[,coeff]
  xsim<-seq(min(x),max(x),((max(x)-min(x))/10000))
  
  sy<-sqrt(sum((mean(resid(mod))-(resid(mod)))^2)/(nrow(frame)-nrow(summary(mod)$coefficients)))
  sx<-sqrt((1/length(x))+(((xsim-mean(x))^2)/((length(x)-1)*var(x))))
  t<-qt(0.975,length(x))
  
  mean<-summary(mod)$coefficients["(Intercept)","Estimate"]+
    summary(mod)$coefficients[coeff,"Estimate"]*xsim
  ci.up<-mean+(t*sy*sx)
  ci.low<-mean-(t*sy*sx)
  
  out<-data.frame(xsim,mean,ci.up,ci.low)
  return(out)
}##run to create data.frame to store booted CI's

mb<-lmer(AGBGI~sqrtPS+
           logSA+CMIave+MATave+sqrtFDis+logPC1+
           logSA:sqrtFDis+
           logSA:logPC1+
           logSA:CMIave+
           logSA:MATave+
           CMIave:MATave+
           sqrtFDis:logPC1+
           CMIave:sqrtFDis+
           MATave:sqrtFDis+
           CMIave:logPC1+
           MATave:logPC1+
           (1|PLOT_ID)+(1|Prov),can)
summary(mb)$co

mc<-lmer(AGBM~PS+
           logSA+CMIave+MATave+sqrtFDis+sqrtPC1+
           logSA:sqrtFDis+
           logSA:sqrtPC1+
           logSA:CMIave+
           logSA:MATave+
           CMIave:MATave+
           sqrtFDis:sqrtPC1+
           CMIave:sqrtFDis+
           MATave:sqrtFDis+
           CMIave:sqrtPC1+
           MATave:sqrtPC1+
           (1|PLOT_ID)+(1|Prov),can)
summary(mc)$co

ma<-lmer(AGB~logPS+
           logSA+CMIave+MATave+SpFDis+logPC1+
           logSA:SpFDis+
           logSA:logPC1+
           logSA:CMIave+
           logSA:MATave+
           CMIave:MATave+
           SpFDis:logPC1+
           CMIave:SpFDis+
           MATave:SpFDis+
           CMIave:logPC1+
           MATave:logPC1+
           (1|PLOT_ID)+(1|Prov),can)
summary(ma)$co

#Make Table
rownames(summary(mb)$co[-1,])

names<-c("f(PS)","ln(SA)","CMIave","MATave","f(FD)","f(CWMPC1)",
         "ln(SA):f(FD)","ln(SA):f(CWMPC1)","ln(SA):CMIave","ln(SA):MATave",
         "CMIave:MATave",
         "f(FD):f(CWMPC1)",
         "CMIave:f(FD)","MATave:f(FD)",
         "CMIave:f(CWMPC1)","MATave:f(CWMPC1)")
Rep=nrow(summary(mb)$co[-1,])

SS_Table<-data.table(Component=c(rep("Growth",Rep),
                                 rep("Mortality",Rep),
                                 rep("Net biomass change",Rep)),
                     Predictors=c(rep(names,3)))
SS_Table$SS<-(c(anova(mb)[,2],anova(mc)[,2],anova(ma)[,2]))
SS_Table[,":="(Total_SS=sum(SS)),by=Component]
SS_Table[,":="(Percent_SS=SS/Total_SS)]

SS_Table$Predictors<-factor(SS_Table$Predictors,
                            levels=c("f(PS)","ln(SA)","CMIave","MATave","f(FD)","f(CWMPC1)",
                                     "ln(SA):f(FD)","ln(SA):f(CWMPC1)","ln(SA):CMIave","ln(SA):MATave",
                                     "CMIave:MATave",
                                     "f(FD):f(CWMPC1)",
                                     "CMIave:f(FD)","MATave:f(FD)",
                                     "CMIave:f(CWMPC1)","MATave:f(CWMPC1)"))
#Graph
library(ggplot2);library(ggsci);library(scales)

ggplot(SS_Table,aes(x=Component,y=Percent_SS,fill=Predictors))+
  theme_classic()+
  geom_bar(stat="identity", position="fill")

##CONSIDER summarising all the interaction terms as "Others (Interaction terms)".
names<-c("f(PS)","ln(SA)","CMIave","MATave","f(FD)","f(CWMPC1)",rep("Interactions",Rep-6))#-6 = number of fixed eff
Rep=nrow(summary(mb)$co[-1,])

SS_Table<-data.table(Component=c(rep("Growth",Rep),
                                 rep("Mortality",Rep),
                                 rep("Net biomass change",Rep)),
                     Predictors=c(rep(names,3)))
SS_Table$SS<-(c(anova(mb)[,2],anova(mc)[,2],anova(ma)[,2]))
SS_Table[,":="(Total_SS=sum(SS)),by=Component] %>% 
  .[,":="(Percent_SS=SS/Total_SS,
          Percent_SS100=round(SS/Total_SS*100,1))]

#Interactions %
round(SS_Table[Component=="Growth"&Predictors=="Interactions",sum(Percent_SS)]*100,1)
round(SS_Table[Component=="Mortality"&Predictors=="Interactions",sum(Percent_SS)]*100,1)
round(SS_Table[Component=="Net biomass change"&Predictors=="Interactions",sum(Percent_SS)]*100,1)


SS_Table$Predictors<-factor(SS_Table$Predictors,
                            levels=c("f(PS)","ln(SA)","CMIave","MATave","f(FD)","f(CWMPC1)",
                                     "Interactions"))

g<-ggplot(SS_Table,aes(x=Component,y=Percent_SS,fill=Predictors))+
  geom_bar(stat="identity", position="fill")+
  scale_fill_manual(values = c("lightgoldenrod3","turquoise4","darkslategray1","deepskyblue1",
                               "plum1","mediumvioletred","beige"))+
  theme_classic()+
  theme(axis.line.x = element_blank(),
        axis.ticks.x=element_blank(),
        axis.text.x=element_text(size=12,face="bold"),
        #axis.line.y = element_blank(),
        #axis.ticks.y=element_blank(),
        axis.title=element_text(size=12,face="bold"))+
  xlab("")+
  ylab("Relative effect of estimates")
g

tiff("Fig1_Sum_of_Squares_Proportion.tiff",width=2000,height=2000,res=300,compression="lzw")
grid.draw(g)
dev.off()

##
SS_Table[Component=="Growth"&Predictors=="Interactions",sum(Percent_SS100)]
SS_Table[Component=="Mortality"&Predictors=="Interactions",sum(Percent_SS100)]
SS_Table[Component=="Net biomass change"&Predictors=="Interactions",sum(Percent_SS100)]
