#rm(list=ls())
library(lme4);library(lmerTest)
library(nlme)
library(boot);library(Rfit)
library(MuMIn);library(ggplot2)
library(grid);library(gridExtra)
library(gtable);library(plyr)
library(dplyr);library(data.table)
library(MuMIn);options(na.action = "na.fail")
library(glmnet);library(glmnetUtils)
library(SoDA);library(spdep);library(spaMM)

## Growth
#FDis effects depends on CMIave
coefmean<-summary(mb)$co[,1]
coefSE<-summary(mb)$co[,2]
plot_df<-expand.grid(sqrtFDis=can$sqrtFDis,
                     CMIave=round(c(seq(quantile(can$CMIave,0.05)[[1]],
                                        quantile(can$CMIave,0.95)[[1]],length=4),0),2)) %>%
  mutate(mean=coefmean["(Intercept)"]+coefmean["CMIave"]*CMIave+coefmean["sqrtFDis"]*sqrtFDis+
           coefmean["CMIave:sqrtFDis"]*CMIave*sqrtFDis) %>% 
  mutate(up=coefmean["(Intercept)"]+coefmean["CMIave"]*CMIave+coefmean["sqrtFDis"]*sqrtFDis+
           coefmean["CMIave:sqrtFDis"]*CMIave*sqrtFDis+
           coefSE["(Intercept)"]+coefSE["CMIave"]*CMIave+coefSE["sqrtFDis"]*sqrtFDis+
           coefSE["CMIave:sqrtFDis"]*CMIave*sqrtFDis) %>% 
  mutate(low=coefmean["(Intercept)"]+coefmean["CMIave"]*CMIave+coefmean["sqrtFDis"]*sqrtFDis+
           coefmean["CMIave:sqrtFDis"]*CMIave*sqrtFDis-
           (coefSE["(Intercept)"]+coefSE["CMIave"]*CMIave+coefSE["sqrtFDis"]*sqrtFDis+
              coefSE["CMIave:sqrtFDis"]*CMIave*sqrtFDis)) %>% 
  as.data.table()
plot_df[,":="(sqrtFDis1=sqrtFDis*sd(can$sqrtFDis1)+mean(can$sqrtFDis1),CMIave1=CMIave*sd(can$CMIave1)+mean(can$CMIave1))] %>% 
  .[,":="(CMIave=as.factor(round(CMIave,2)),CMIave1=as.factor(round(CMIave1,2)))]
head(plot_df);nrow(plot_df)

CMI_Grow<-ggplot(plot_df,aes(y=mean,x=(sqrtFDis1)^2,color=CMIave))+
  theme_classic()+
  geom_ribbon(aes(x=(sqrtFDis1)^2,ymin=low,ymax=up,
                  group=CMIave),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1.1)+
  scale_colour_manual(values=c("maroon4","maroon2","black","lightslateblue","dodgerblue4"),name="",
                      labels=c("-0.83841231"="1.00","-0.4126802475"="2.12","0.013051815"="3.25",
                               "0.4387838775"="4.37","0.86451594"="5.31","0"="Mean"),
                      guide=guide_legend(override.aes = list(colour=NA,fill=NA)))+
  xlab("")+
  ylab(expression(paste("Growth (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x= element_blank(), axis.line.y = element_line(),
        legend.title.align = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))
CMI_Grow<-CMI_Grow+annotate("text",x= 0.15,y=4.8,label="sqrt(FD):~italic(P) <0.001",parse=TRUE,size=3.5)
CMI_Grow<-CMI_Grow+annotate("text",x= 0.15,y=4.5,label="CMIave%*%sqrt(FD):~italic(P) == 0.009",parse=TRUE,size=3.5)
CMI_Grow

summary(mb)$co

#FDis effect depends on MATave
coefmean<-summary(mb)$co[,1]
coefSE<-summary(mb)$co[,2]
plot_df<-expand.grid(sqrtFDis=can$sqrtFDis,
                     MATave=round(c(seq(quantile(can$MATave,0.05)[[1]],
                                        quantile(can$MATave,0.95)[[1]],length=4),0),2)) %>%
  mutate(mean=coefmean["(Intercept)"]+coefmean["MATave"]*MATave+coefmean["sqrtFDis"]*sqrtFDis+
           coefmean["MATave:sqrtFDis"]*MATave*sqrtFDis) %>% 
  mutate(up=coefmean["(Intercept)"]+coefmean["MATave"]*MATave+coefmean["sqrtFDis"]*sqrtFDis+
           coefmean["MATave:sqrtFDis"]*MATave*sqrtFDis+
           coefSE["(Intercept)"]+coefSE["MATave"]*MATave+coefSE["sqrtFDis"]*sqrtFDis+
           coefSE["MATave:sqrtFDis"]*MATave*sqrtFDis) %>% 
  mutate(low=coefmean["(Intercept)"]+coefmean["MATave"]*MATave+coefmean["sqrtFDis"]*sqrtFDis+
           coefmean["MATave:sqrtFDis"]*MATave*sqrtFDis-
           (coefSE["(Intercept)"]+coefSE["MATave"]*MATave+coefSE["sqrtFDis"]*sqrtFDis+
              coefSE["MATave:sqrtFDis"]*MATave*sqrtFDis)) %>% 
  as.data.table()
plot_df[,":="(sqrtFDis1=sqrtFDis*sd(can$sqrtFDis1)+mean(can$sqrtFDis1),MATave1=MATave*sd(can$MATave1)+mean(can$MATave1))] %>% 
  .[,":="(MATave=as.factor(round(MATave,2)),MATave1=as.factor(round(MATave1,2)))]
head(plot_df);nrow(plot_df)

MAT_Grow<-ggplot(plot_df,aes(y=mean,x=(sqrtFDis1)^2,color=MATave))+
  theme_classic()+
  geom_ribbon(aes(x=(sqrtFDis1)^2,ymin=low,ymax=up,
                  group=MATave),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1.1)+
  scale_colour_manual(values=c("violetred3","violet","black","turquoise","turquoise4"),name="",
                      labels=c("-0.83841231"="1.00", "-0.4126802475"="2.12","0.013051815"="3.25",
                               "0.4387838775"="4.37","0.86451594"="5.31","0"="Mean"),
                      guide=guide_legend(override.aes = list(colour=NA,fill=NA)))+
  xlab("")+
  ylab(expression(paste("Growth (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x= element_blank(), axis.line.y = element_line(),
        legend.title.align  = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))
MAT_Grow<-MAT_Grow+annotate("text",x= 0.15,y=5,label="MATave%*%sqrt(FD):~italic(P) <0.001",parse=TRUE,size=3.5)
MAT_Grow

summary(mb)$co

#PC1 effects depends on CMIave
coefmean<-summary(mb)$co[,1]
coefSE<-summary(mb)$co[,2]
plot_df<-expand.grid(logPC1=can$logPC1,
                     CMIave=round(c(seq(quantile(can$CMIave,0.05)[[1]],
                                        quantile(can$CMIave,0.95)[[1]],length=4),0),2)) %>%
  mutate(mean=coefmean["(Intercept)"]+coefmean["CMIave"]*CMIave+coefmean["logPC1"]*logPC1+
           coefmean["CMIave:logPC1"]*CMIave*logPC1) %>% 
  mutate(up=coefmean["(Intercept)"]+coefmean["CMIave"]*CMIave+coefmean["logPC1"]*logPC1+
           coefmean["CMIave:logPC1"]*CMIave*logPC1+
           coefSE["(Intercept)"]+coefSE["CMIave"]*CMIave+coefSE["logPC1"]*logPC1+
           coefSE["CMIave:logPC1"]*CMIave*logPC1) %>% 
  mutate(low=coefmean["(Intercept)"]+coefmean["CMIave"]*CMIave+coefmean["logPC1"]*logPC1+
           coefmean["CMIave:logPC1"]*CMIave*logPC1-
           (coefSE["(Intercept)"]+coefSE["CMIave"]*CMIave+coefSE["logPC1"]*logPC1+
              coefSE["CMIave:logPC1"]*CMIave*logPC1)) %>% 
  as.data.table()
plot_df[,":="(logPC11=logPC1*sd(can$logPC11)+mean(can$logPC11),CMIave1=CMIave*sd(can$CMIave1)+mean(can$CMIave1))] %>% 
  .[,":="(CMIave=as.factor(round(CMIave,2)),CMIave1=as.factor(round(CMIave1,2)))]
head(plot_df);nrow(plot_df)

CMI_Grow_PC1<-ggplot(plot_df,aes(y=mean,x=exp(logPC11)-abs(min(can$SpPC11))-1,color=CMIave))+
  theme_classic()+
  geom_ribbon(aes(x=exp(logPC11)-abs(min(can$SpPC11))-1,ymin=low,ymax=up,
                  group=CMIave),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1.1)+
  scale_colour_manual(values=c("maroon4","maroon2","black","lightslateblue","dodgerblue4"),name="",
                      labels=c("-0.83841231"="1.00","-0.4126802475"="2.12","0.013051815"="3.25",
                               "0.4387838775"="4.37","0.86451594"="5.31","0"="Mean"),
                      guide=guide_legend(override.aes = list(colour=NA,fill=NA)))+
  xlab("")+
  ylab(expression(paste("Growth (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x= element_blank(), axis.line.y = element_line(),
        legend.title.align = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))
CMI_Grow_PC1<-CMI_Grow_PC1+annotate("text",x= 1.25,y=4.8,label="ln(CWM[PC1]):~italic(P) <0.001",parse=TRUE,size=3.5)
CMI_Grow_PC1<-CMI_Grow_PC1+annotate("text",x= 1.25,y=4.5,label="CMIave%*%ln(CWM[PC1]):~italic(P) <0.001",parse=TRUE,size=3.5)
CMI_Grow_PC1

summary(mb)$co

#PC1 effect depends on MATave
coefmean<-summary(mb)$co[,1]
coefSE<-summary(mb)$co[,2]
plot_df<-expand.grid(logPC1=can$logPC1,
                     MATave=round(c(seq(quantile(can$MATave,0.05)[[1]],
                                        quantile(can$MATave,0.95)[[1]],length=4),0),2)) %>%
  mutate(mean=coefmean["(Intercept)"]+coefmean["MATave"]*MATave+coefmean["logPC1"]*logPC1+
           coefmean["MATave:logPC1"]*MATave*logPC1) %>% 
  mutate(up=coefmean["(Intercept)"]+coefmean["MATave"]*MATave+coefmean["logPC1"]*logPC1+
           coefmean["MATave:logPC1"]*MATave*logPC1+
           coefSE["(Intercept)"]+coefSE["MATave"]*MATave+coefSE["logPC1"]*logPC1+
           coefSE["MATave:logPC1"]*MATave*logPC1) %>% 
  mutate(low=coefmean["(Intercept)"]+coefmean["MATave"]*MATave+coefmean["logPC1"]*logPC1+
           coefmean["MATave:logPC1"]*MATave*logPC1-
           (coefSE["(Intercept)"]+coefSE["MATave"]*MATave+coefSE["logPC1"]*logPC1+
              coefSE["MATave:logPC1"]*MATave*logPC1)) %>% 
  as.data.table()
plot_df[,":="(logPC11=logPC1*sd(can$logPC11)+mean(can$logPC11),MATave1=MATave*sd(can$MATave1)+mean(can$MATave1))] %>% 
  .[,":="(MATave=as.factor(round(MATave,2)),MATave1=as.factor(round(MATave1,2)))]
head(plot_df);nrow(plot_df)

MAT_Grow_PC1<-ggplot(plot_df,aes(y=mean,x=exp(logPC11)-abs(min(can$SpPC11))-1,color=MATave))+
  theme_classic()+
  geom_ribbon(aes(x=exp(logPC11)-abs(min(can$SpPC11))-1,ymin=low,ymax=up,
                  group=MATave),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1.1)+
  scale_colour_manual(values=c("violetred3","violet","black","turquoise","turquoise4"),name="",
                      labels=c("-0.83841231"="1.00", "-0.4126802475"="2.12","0.013051815"="3.25",
                               "0.4387838775"="4.37","0.86451594"="5.31","0"="Mean"),
                      guide=guide_legend(override.aes = list(colour=NA,fill=NA)))+
  xlab("")+
  ylab(expression(paste("Growth (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x= element_blank(), axis.line.y = element_line(),
        legend.title.align  = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))
MAT_Grow_PC1<-MAT_Grow_PC1+annotate("text",x= 1.25,y=5,label="MATave%*%ln(CWM[PC1]):~italic(P) <0.001",parse=TRUE,size=3.5)
MAT_Grow_PC1

summary(mb)$co

## Mortality
#FDis effects depends on CMIave
coefmean<-summary(mc)$co[,1]
coefSE<-summary(mc)$co[,2]
plot_df<-expand.grid(sqrtFDis=can$sqrtFDis,
                     CMIave=round(c(seq(quantile(can$CMIave,0.05)[[1]],
                                        quantile(can$CMIave,0.95)[[1]],length=4),0),2)) %>%
  
  mutate(mean=coefmean["(Intercept)"]+coefmean["CMIave"]*CMIave+coefmean["sqrtFDis"]*sqrtFDis+
           coefmean["CMIave:sqrtFDis"]*CMIave*sqrtFDis) %>% 
  mutate(up=coefmean["(Intercept)"]+coefmean["CMIave"]*CMIave+coefmean["sqrtFDis"]*sqrtFDis+
           coefmean["CMIave:sqrtFDis"]*CMIave*sqrtFDis+
           coefSE["(Intercept)"]+coefSE["CMIave"]*CMIave+coefSE["sqrtFDis"]*sqrtFDis+
           coefSE["CMIave:sqrtFDis"]*CMIave*sqrtFDis) %>% 
  mutate(low=coefmean["(Intercept)"]+coefmean["CMIave"]*CMIave+coefmean["sqrtFDis"]*sqrtFDis+
           coefmean["CMIave:sqrtFDis"]*CMIave*sqrtFDis-
           (coefSE["(Intercept)"]+coefSE["CMIave"]*CMIave+coefSE["sqrtFDis"]*sqrtFDis+
              coefSE["CMIave:sqrtFDis"]*CMIave*sqrtFDis)) %>% 
  as.data.table()
plot_df[,":="(sqrtFDis1=sqrtFDis*sd(can$sqrtFDis1)+mean(can$sqrtFDis1),CMIave1=CMIave*sd(can$CMIave1)+mean(can$CMIave1))] %>% 
  .[,":="(CMIave=as.factor(round(CMIave,2)),CMIave1=as.factor(round(CMIave1,2)))]
head(plot_df);nrow(plot_df)

seq(quantile(can$CMIave1,0.05)[[1]],quantile(can$CMIave1,0.95)[[1]],length=4);mean(can$CMIave1)
CMI_Mort<-ggplot(plot_df,aes(y=mean,x=(sqrtFDis1)^2,color=CMIave))+
  theme_classic()+
  geom_ribbon(aes(x=(sqrtFDis1)^2, ymin=low,ymax=up,group=CMIave),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1.1)+
  scale_colour_manual(values=c("maroon4","maroon2","black","lightslateblue","dodgerblue4"),name="CMIave (cm)",
                      labels=c("-1.42"="1.2", "-0.54"="35.8","0.33"="70.3","1.2"="104.8","0"="Mean (57.4)"))+
  xlab("")+
  ylab(expression(paste("Mortality (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x= element_blank(), axis.line.y = element_line(),
        legend.title.align  = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour="black"))
CMI_Mort<-CMI_Mort+annotate("text",x= 0.15,y=2.3,label="sqrt(FD):~italic(P) <0.001",parse=TRUE,size=3.5)
CMI_Mort<-CMI_Mort+annotate("text",x= 0.15,y=2.2,label="CMIave%*%sqrt(FD):~italic(P) == 0.005",parse=TRUE,size=3.5)
CMI_Mort

summary(mc)$co

#FDis effect depends on MATave
coefmean<-summary(mc)$co[,1]
coefSE<-summary(mc)$co[,2]
plot_df<-expand.grid(sqrtFDis=can$sqrtFDis,
                     MATave=round(c(seq(quantile(can$MATave,0.05)[[1]],
                                        quantile(can$MATave,0.95)[[1]],length=4),0),2)) %>%
  mutate(mean=coefmean["(Intercept)"]+coefmean["MATave"]*MATave+coefmean["sqrtFDis"]*sqrtFDis+
           coefmean["MATave:sqrtFDis"]*MATave*sqrtFDis) %>% 
  mutate(up=coefmean["(Intercept)"]+coefmean["MATave"]*MATave+coefmean["sqrtFDis"]*sqrtFDis+
           coefmean["MATave:sqrtFDis"]*MATave*sqrtFDis+
           coefSE["(Intercept)"]+coefSE["MATave"]*MATave+coefSE["sqrtFDis"]*sqrtFDis+
           coefSE["MATave:sqrtFDis"]*MATave*sqrtFDis) %>% 
  mutate(low=coefmean["(Intercept)"]+coefmean["MATave"]*MATave+coefmean["sqrtFDis"]*sqrtFDis+
           coefmean["MATave:sqrtFDis"]*MATave*sqrtFDis-
           (coefSE["(Intercept)"]+coefSE["MATave"]*MATave+coefSE["sqrtFDis"]*sqrtFDis+
              coefSE["MATave:sqrtFDis"]*MATave*sqrtFDis)) %>% 
  as.data.table()

plot_df[,":="(sqrtFDis1=sqrtFDis*sd(can$sqrtFDis1)+mean(can$sqrtFDis1),MATave1=MATave*sd(can$MATave1)+mean(can$MATave1))] %>% 
  .[,":="(MATave=as.factor(round(MATave,2)),MATave1=as.factor(round(MATave1,2)))]
head(plot_df);nrow(plot_df)

seq(quantile(can$MATave1,0.05)[[1]],quantile(can$MATave1,0.95)[[1]],length=4);mean(can$MATave1)
MAT_Mort<-ggplot(plot_df,aes(y=mean,x=(sqrtFDis1)^2,color=MATave))+
  theme_classic()+
  geom_ribbon(aes(x=(sqrtFDis1)^2, ymin=low,ymax=up,group=MATave),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1.1)+
  scale_colour_manual(values=c("violetred3","violet","black","turquoise","turquoise4"),name=expression(paste("MATave (",~degree*C,")")),
                      labels=c("-1.66"="-1.6", "-0.58"="1.3","0.5"="4.2","1.58"="7.1","0"="Mean (2.9)"))+
  xlab("")+
  ylab(expression(paste("Mortality (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x= element_blank(), axis.line.y = element_line(),
        legend.title.align = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour="black"))
MAT_Mort<-MAT_Mort+annotate("text",x= 0.15,y=2.6,label="MATave%*%sqrt(FD):~italic(P) == 0.528",parse=TRUE,size=3.5)
MAT_Mort

summary(mc)$co

#PC1 effects depends on CMIave
coefmean<-summary(mc)$co[,1]
coefSE<-summary(mc)$co[,2]
plot_df<-expand.grid(sqrtPC1=can$sqrtPC1,
                     CMIave=round(c(seq(quantile(can$CMIave,0.05)[[1]],
                                        quantile(can$CMIave,0.95)[[1]],length=4),0),2)) %>%
  mutate(mean=coefmean["(Intercept)"]+coefmean["CMIave"]*CMIave+coefmean["sqrtPC1"]*sqrtPC1+
           coefmean["CMIave:sqrtPC1"]*CMIave*sqrtPC1) %>% 
  mutate(up=coefmean["(Intercept)"]+coefmean["CMIave"]*CMIave+coefmean["sqrtPC1"]*sqrtPC1+
           coefmean["CMIave:sqrtPC1"]*CMIave*sqrtPC1+
           coefSE["(Intercept)"]+coefSE["CMIave"]*CMIave+coefSE["sqrtPC1"]*sqrtPC1+
           coefSE["CMIave:sqrtPC1"]*CMIave*sqrtPC1) %>% 
  mutate(low=coefmean["(Intercept)"]+coefmean["CMIave"]*CMIave+coefmean["sqrtPC1"]*sqrtPC1+
           coefmean["CMIave:sqrtPC1"]*CMIave*sqrtPC1-
           (coefSE["(Intercept)"]+coefSE["CMIave"]*CMIave+coefSE["sqrtPC1"]*sqrtPC1+
              coefSE["CMIave:sqrtPC1"]*CMIave*sqrtPC1)) %>% 
  as.data.table()
plot_df[,":="(sqrtPC11=sqrtPC1*sd(can$sqrtPC11)+mean(can$sqrtPC11),CMIave1=CMIave*sd(can$CMIave1)+mean(can$CMIave1))] %>% 
  .[,":="(CMIave=as.factor(round(CMIave,2)),CMIave1=as.factor(round(CMIave1,2)))]
head(plot_df);nrow(plot_df)

CMI_Mort_PC1<-ggplot(plot_df,aes(y=mean,x=(sqrtPC11)^2-abs(min(can$SpPC11))-1,color=CMIave))+
  theme_classic()+
  geom_ribbon(aes(x=(sqrtPC11)^2-abs(min(can$SpPC11))-1, ymin=low,ymax=up,group=CMIave),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1.1)+
  scale_colour_manual(values=c("maroon4","maroon2","black","lightslateblue","dodgerblue4"),name="CMIave (cm)",
                      labels=c("-1.42"="1.2", "-0.54"="35.8","0.33"="70.3","1.2"="104.8","0"="Mean (57.4)"))+
  xlab("")+
  ylab(expression(paste("Mortality (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x= element_blank(), axis.line.y = element_line(),
        legend.title.align = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour="black"))
CMI_Mort_PC1<-CMI_Mort_PC1+annotate("text",x= 0.15,y=2.83,label="sqrt(CWM[PC1]):~italic(P) <0.001",parse=TRUE,size=3.5)
CMI_Mort_PC1<-CMI_Mort_PC1+annotate("text",x= 0.15,y=2.65,label="CMIave%*%sqrt(CWM[PC1]):~italic(P) == 0.011",parse=TRUE,size=3.5)
CMI_Mort_PC1

summary(mc)$co

#PC1 effect depends on MATave
coefmean<-summary(mc)$co[,1]
coefSE<-summary(mc)$co[,2]
plot_df<-expand.grid(sqrtPC1=can$sqrtPC1,
                     MATave=round(c(seq(quantile(can$MATave,0.05)[[1]],
                                        quantile(can$MATave,0.95)[[1]],length=4),0),2)) %>%
  mutate(mean=coefmean["(Intercept)"]+coefmean["MATave"]*MATave+coefmean["sqrtPC1"]*sqrtPC1+
           coefmean["MATave:sqrtPC1"]*MATave*sqrtPC1) %>% 
  mutate(up=coefmean["(Intercept)"]+coefmean["MATave"]*MATave+coefmean["sqrtPC1"]*sqrtPC1+
           coefmean["MATave:sqrtPC1"]*MATave*sqrtPC1+
           coefSE["(Intercept)"]+coefSE["MATave"]*MATave+coefSE["sqrtPC1"]*sqrtPC1+
           coefSE["MATave:sqrtPC1"]*MATave*sqrtPC1) %>% 
  mutate(low=coefmean["(Intercept)"]+coefmean["MATave"]*MATave+coefmean["sqrtPC1"]*sqrtPC1+
           coefmean["MATave:sqrtPC1"]*MATave*sqrtPC1-
           (coefSE["(Intercept)"]+coefSE["MATave"]*MATave+coefSE["sqrtPC1"]*sqrtPC1+
              coefSE["MATave:sqrtPC1"]*MATave*sqrtPC1)) %>% 
  as.data.table()
plot_df[,":="(sqrtPC11=sqrtPC1*sd(can$sqrtPC11)+mean(can$sqrtPC11),MATave1=MATave*sd(can$MATave1)+mean(can$MATave1))] %>% 
  .[,":="(MATave=as.factor(round(MATave,2)),MATave1=as.factor(round(MATave1,2)))]
head(plot_df);nrow(plot_df)

MAT_Mort_PC1<-ggplot(plot_df,aes(y=mean,x=(sqrtPC11)^2-abs(min(can$SpPC11))-1,color=MATave))+
  theme_classic()+
  geom_ribbon(aes(x=(sqrtPC11)^2-abs(min(can$SpPC11))-1, ymin=low,ymax=up,group=MATave),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1.1)+
  scale_colour_manual(values=c("violetred3","violet","black","turquoise","turquoise4"),name=expression(paste("MATave (",~degree*C,")")),
                      labels=c("-1.66"="-1.6", "-0.58"="1.3","0.5"="4.2","1.58"="7.1","0"="Mean (2.9)"))+
  xlab("")+
  ylab(expression(paste("Mortality (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x= element_blank(), axis.line.y = element_line(),
        legend.title.align = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour="black"))
MAT_Mort_PC1<-MAT_Mort_PC1+annotate("text",x= 0.15,y=3,label="MATave%*%sqrt(CWM[PC1]):~italic(P) <0.001",parse=TRUE,size=3.5)
MAT_Mort_PC1

summary(mc)$co

## Net biomass change
#FDis effects depends on CMIave
coefmean<-summary(ma)$co[,1]
coefSE<-summary(ma)$co[,2]
plot_df<-expand.grid(SpFDis=can$SpFDis,
                     CMIave=round(c(seq(quantile(can$CMIave,0.05)[[1]],
                                        quantile(can$CMIave,0.95)[[1]],length=4),0),2)) %>%
  mutate(mean=coefmean["(Intercept)"]+coefmean["CMIave"]*CMIave+coefmean["SpFDis"]*SpFDis+
           coefmean["CMIave:SpFDis"]*CMIave*SpFDis) %>% 
  mutate(up=coefmean["(Intercept)"]+coefmean["CMIave"]*CMIave+coefmean["SpFDis"]*SpFDis+
           coefmean["CMIave:SpFDis"]*CMIave*SpFDis+
           coefSE["(Intercept)"]+coefSE["CMIave"]*CMIave+coefSE["SpFDis"]*SpFDis+
           coefSE["CMIave:SpFDis"]*CMIave*SpFDis) %>% 
  mutate(low=coefmean["(Intercept)"]+coefmean["CMIave"]*CMIave+coefmean["SpFDis"]*SpFDis+
           coefmean["CMIave:SpFDis"]*CMIave*SpFDis-
           (coefSE["(Intercept)"]+coefSE["CMIave"]*CMIave+coefSE["SpFDis"]*SpFDis+
              coefSE["CMIave:SpFDis"]*CMIave*SpFDis)) %>% 
  as.data.table()
plot_df[,":="(SpFDis1=SpFDis*sd(can$SpFDis1)+mean(can$SpFDis1),CMIave1=CMIave*sd(can$CMIave1)+mean(can$CMIave1))] %>% 
  .[,":="(CMIave=as.factor(round(CMIave,2)),CMIave1=as.factor(round(CMIave1,2)))]
head(plot_df);nrow(plot_df)

CMI_NBC<-ggplot(plot_df,aes(y=mean,x=(SpFDis1),color=CMIave))+
  theme_classic()+
  geom_ribbon(aes(x=(SpFDis1), ymin=low,ymax=up,group=CMIave),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1.1)+
  scale_colour_manual(values=c("maroon4","maroon2","black","lightslateblue","dodgerblue4"),name="",
                      labels=c("-0.83841231"="1.00", "-0.4126802475"="2.12","0.013051815"="3.25",
                               "0.4387838775"="4.37","0.86451594"="5.31","0"="Mean"),
                      guide=guide_legend(override.aes = list(colour=NA,fill=NA)))+
  xlab(expression(paste("Functional diversity (FD)")))+
  ylab(expression(paste("Net biomass change (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.line.y = element_line(),
        legend.title.align = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))
CMI_NBC<-CMI_NBC+annotate("text",x= 0.15,y=2.8,label="FD:~italic(P) <0.001",parse=TRUE,size=3.5)
CMI_NBC<-CMI_NBC+annotate("text",x= 0.15,y=2.5,label="CMIave%*%FD:~italic(P) == 0.014",parse=TRUE,size=3.5)
CMI_NBC

summary(ma)$co

#FDis effect depends on MATave
coefmean<-summary(ma)$co[,1]
coefSE<-summary(ma)$co[,2]
plot_df<-expand.grid(SpFDis=can$SpFDis,
                     MATave=round(c(seq(quantile(can$MATave,0.05)[[1]],
                                        quantile(can$MATave,0.95)[[1]],length=4),0),2)) %>%
  mutate(mean=coefmean["(Intercept)"]+coefmean["MATave"]*MATave+coefmean["SpFDis"]*SpFDis+
           coefmean["MATave:SpFDis"]*MATave*SpFDis) %>% 
  mutate(up=coefmean["(Intercept)"]+coefmean["MATave"]*MATave+coefmean["SpFDis"]*SpFDis+
           coefmean["MATave:SpFDis"]*MATave*SpFDis+
           coefSE["(Intercept)"]+coefSE["MATave"]*MATave+coefSE["SpFDis"]*SpFDis+
           coefSE["MATave:SpFDis"]*MATave*SpFDis) %>% 
  mutate(low=coefmean["(Intercept)"]+coefmean["MATave"]*MATave+coefmean["SpFDis"]*SpFDis+
           coefmean["MATave:SpFDis"]*MATave*SpFDis-
           (coefSE["(Intercept)"]+coefSE["MATave"]*MATave+coefSE["SpFDis"]*SpFDis+
              coefSE["MATave:SpFDis"]*MATave*SpFDis)) %>% 
  as.data.table()
plot_df[,":="(SpFDis1=SpFDis*sd(can$SpFDis1)+mean(can$SpFDis1),MATave1=MATave*sd(can$MATave1)+mean(can$MATave1))] %>% 
  .[,":="(MATave=as.factor(round(MATave,2)),MATave1=as.factor(round(MATave1,2)))]
head(plot_df);nrow(plot_df)

MAT_NBC<-ggplot(plot_df,aes(y=mean,x=(SpFDis1),color=MATave))+
  theme_classic()+
  geom_ribbon(aes(x=(SpFDis1), ymin=low,ymax=up,group=MATave),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1.1)+
  scale_colour_manual(values=c("violetred3","violet","black","turquoise","turquoise4"),name="",
                      labels=c("-0.83841231"="1.00", "-0.4126802475"="2.12","0.013051815"="3.25",
                               "0.4387838775"="4.37","0.86451594"="5.31","0"="Mean"),
                      guide=guide_legend(override.aes = list(colour=NA,fill=NA)))+
  xlab(expression(paste("Functional diversity (FD)")))+
  ylab(expression(paste("Net biomass change (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.line.y = element_line(),
        legend.title.align  = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))
MAT_NBC<-MAT_NBC+annotate("text",x= 0.15,y=2.5,label="MATave%*%FD:~italic(P) == 0.556",parse=TRUE,size=3.5)
MAT_NBC

summary(ma)$co

#PC1 effects depends on CMIave
coefmean<-summary(ma)$co[,1]
coefSE<-summary(ma)$co[,2]
plot_df<-expand.grid(logPC1=can$logPC1,
                     CMIave=round(c(seq(quantile(can$CMIave,0.05)[[1]],
                                        quantile(can$CMIave,0.95)[[1]],length=4),0),2)) %>%
  mutate(mean=coefmean["(Intercept)"]+coefmean["CMIave"]*CMIave+coefmean["logPC1"]*logPC1+
           coefmean["CMIave:logPC1"]*CMIave*logPC1) %>% 
  mutate(up=coefmean["(Intercept)"]+coefmean["CMIave"]*CMIave+coefmean["logPC1"]*logPC1+
           coefmean["CMIave:logPC1"]*CMIave*logPC1+
           coefSE["(Intercept)"]+coefSE["CMIave"]*CMIave+coefSE["logPC1"]*logPC1+
           coefSE["CMIave:logPC1"]*CMIave*logPC1) %>% 
  mutate(low=coefmean["(Intercept)"]+coefmean["CMIave"]*CMIave+coefmean["logPC1"]*logPC1+
           coefmean["CMIave:logPC1"]*CMIave*logPC1-
           (coefSE["(Intercept)"]+coefSE["CMIave"]*CMIave+coefSE["logPC1"]*logPC1+
              coefSE["CMIave:logPC1"]*CMIave*logPC1)) %>% 
  as.data.table()
plot_df[,":="(logPC11=logPC1*sd(can$logPC11)+mean(can$logPC11),CMIave1=CMIave*sd(can$CMIave1)+mean(can$CMIave1))] %>% 
  .[,":="(CMIave=as.factor(round(CMIave,2)),CMIave1=as.factor(round(CMIave1,2)))]
head(plot_df);nrow(plot_df)

CMI_NBC_PC1<-ggplot(plot_df,aes(y=mean,x=exp(logPC11)-abs(min(can$SpPC11))-1,color=CMIave))+
  theme_classic()+
  geom_ribbon(aes(x=exp(logPC11)-abs(min(can$SpPC11))-1, ymin=low,ymax=up,group=CMIave),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1.1)+
  scale_colour_manual(values=c("maroon4","maroon2","black","lightslateblue","dodgerblue4"),name="",
                      labels=c("-0.83841231"="1.00","-0.4126802475"="2.12","0.013051815"="3.25",
                               "0.4387838775"="4.37","0.86451594"="5.31","0"="Mean"),
                      guide=guide_legend(override.aes = list(colour=NA,fill=NA)))+
  #xlab(expression('Functional identity'))+
  labs(x=expression(paste('Functional identity ',(CWM[PC1]))))+
  ylab(expression(paste("Net biomass change (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.line.y = element_line(),
        legend.title.align  = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))
CMI_NBC_PC1<-CMI_NBC_PC1+annotate("text",x= 1.25,y=2.8,label="ln(CWM[PC1]):~italic(P) <0.001",parse=TRUE,size=3.5)
CMI_NBC_PC1<-CMI_NBC_PC1+annotate("text",x= 1.25,y=2.5,label="CMIave%*%ln(CWM[PC1]):~italic(P) == 0.022",parse=TRUE,size=3.5)
CMI_NBC_PC1

summary(ma)$co

#PC1 effect depends on MATave
coefmean<-summary(ma)$co[,1]
coefSE<-summary(ma)$co[,2]
plot_df<-expand.grid(logPC1=can$logPC1,
                     MATave=round(c(seq(quantile(can$MATave,0.05)[[1]],
                                        quantile(can$MATave,0.95)[[1]],length=4),0),2)) %>%
  mutate(mean=coefmean["(Intercept)"]+coefmean["MATave"]*MATave+coefmean["logPC1"]*logPC1+
           coefmean["MATave:logPC1"]*MATave*logPC1) %>% 
  mutate(up=coefmean["(Intercept)"]+coefmean["MATave"]*MATave+coefmean["logPC1"]*logPC1+
           coefmean["MATave:logPC1"]*MATave*logPC1+
           coefSE["(Intercept)"]+coefSE["MATave"]*MATave+coefSE["logPC1"]*logPC1+
           coefSE["MATave:logPC1"]*MATave*logPC1) %>% 
  mutate(low=coefmean["(Intercept)"]+coefmean["MATave"]*MATave+coefmean["logPC1"]*logPC1+
           coefmean["MATave:logPC1"]*MATave*logPC1-
           (coefSE["(Intercept)"]+coefSE["MATave"]*MATave+coefSE["logPC1"]*logPC1+
              coefSE["MATave:logPC1"]*MATave*logPC1)) %>% 
  as.data.table()
plot_df[,":="(logPC11=logPC1*sd(can$logPC11)+mean(can$logPC11),MATave1=MATave*sd(can$MATave1)+mean(can$MATave1))] %>% 
  .[,":="(MATave=as.factor(round(MATave,2)),MATave1=as.factor(round(MATave1,2)))]
head(plot_df);nrow(plot_df)

MAT_NBC_PC1<-ggplot(plot_df,aes(y=mean,x=exp(logPC11)-abs(min(can$SpPC11))-1,color=MATave))+
  theme_classic()+
  geom_ribbon(aes(x=exp(logPC11)-abs(min(can$SpPC11))-1, ymin=low,ymax=up,group=MATave),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1.1)+
  scale_colour_manual(values=c("violetred3","violet","black","turquoise","turquoise4"),name="",
                      labels=c("-0.83841231"="1.00", "-0.4126802475"="2.12","0.013051815"="3.25",
                               "0.4387838775"="4.37","0.86451594"="5.31","0"="Mean"),
                      guide=guide_legend(override.aes = list(colour=NA,fill=NA)))+
  labs(x=expression(paste('Functional identity ',(CWM[PC1]))))+
  #xlab(expression(Functional identity))+
  ylab(expression(paste("Net biomass change (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.line.y = element_line(),
        legend.title.align  = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))
MAT_NBC_PC1<-MAT_NBC_PC1+annotate("text",x= 1.25,y=2.5,label="MATave%*%ln(CWM[PC1]):~italic(P) <0.001",parse=TRUE,size=3.5)
MAT_NBC_PC1

summary(ma)$co

dev.list() # s܂BŁARStudioGD̕\Ȃ΁A̃R[hsĂB
RStudioGD() #@łƂǂɂȂƂ܂B

#### Bind figures ####
rbind_gtable_max <- function(...){
  gtl <- list(...)
  stopifnot(all(sapply(gtl, is.gtable)))
  bind2 <- function (x, y) 
  {
    stopifnot(ncol(x) == ncol(y))
    if (nrow(x) == 0) 
      return(y)
    if (nrow(y) == 0) 
      return(x)
    y$layout$t <- y$layout$t + nrow(x)
    y$layout$b <- y$layout$b + nrow(x)
    x$layout <- rbind(x$layout, y$layout)
    x$heights <- gtable:::insert.unit(x$heights, y$heights)
    x$rownames <- c(x$rownames, y$rownames)
    x$widths <- grid::unit.pmax(x$widths, y$widths)
    x$grobs <- append(x$grobs, y$grobs)
    x
  }
  
  Reduce(bind2, gtl)
}

#FDis bind
g1 <- ggplotGrob(CMI_Grow)
g2 <- ggplotGrob(CMI_Mort)
g3 <- ggplotGrob(CMI_NBC)

h1 <- ggplotGrob(MAT_Grow)
h2 <- ggplotGrob(MAT_Mort)
h3 <- ggplotGrob(MAT_NBC)

maxWidth = unit.pmax(g1$widths[2:3], g2$widths[2:3], g3$widths[2:3])
g1$widths[2:3] <- maxWidth
g2$widths[2:3] <- maxWidth
g3$widths[2:3] <- maxWidth

maxWidth = unit.pmax(h1$widths[2:3], h2$widths[2:3], h3$widths[2:3])
h1$widths[2:3] <- maxWidth
h2$widths[2:3] <- maxWidth
h3$widths[2:3] <- maxWidth

tiff("Fig3_sqrtFDis_effects_by_CMIave_MAT.tiff",width=2500,height=3000,res=300,compression="lzw")
grid.draw(cbind(rbind(g1,g2,g3,size="last"),rbind(h1,h2,h3,size="last"),size="first"))
grid.text("(a)",x=unit(0.02,"npc"),y=unit(0.993,"npc"),gp=gpar(fontsize=14,font=2))
grid.text("(b)",x=unit(0.52,"npc"),y=unit(0.993,"npc"),gp=gpar(fontsize=14,font=2))

dev.off()

#PC1 bind
i1 <- ggplotGrob(CMI_Grow_PC1)
i2 <- ggplotGrob(CMI_Mort_PC1)
i3 <- ggplotGrob(CMI_NBC_PC1)

j1 <- ggplotGrob(MAT_Grow_PC1)
j2 <- ggplotGrob(MAT_Mort_PC1)
j3 <- ggplotGrob(MAT_NBC_PC1)

maxWidth = unit.pmax(i1$widths[2:3], i2$widths[2:3], i3$widths[2:3])
i1$widths[2:3] <- maxWidth
i2$widths[2:3] <- maxWidth
i3$widths[2:3] <- maxWidth

maxWidth = unit.pmax(j1$widths[2:3], j2$widths[2:3], j3$widths[2:3])
j1$widths[2:3] <- maxWidth
j2$widths[2:3] <- maxWidth
j3$widths[2:3] <- maxWidth

tiff("Fig4_PC1_effects_by_CMIave_MAT_PC1.tiff",width=2500,height=3000,res=300,compression="lzw")
grid.draw(cbind(rbind(i1,i2,i3,size="last"),rbind(j1,j2,j3,size="last"),size="first"))
grid.text("(a)",x=unit(0.02,"npc"),y=unit(0.993,"npc"),gp=gpar(fontsize=14,font=2))
grid.text("(b)",x=unit(0.52,"npc"),y=unit(0.993,"npc"),gp=gpar(fontsize=14,font=2))

dev.off()
