#rm(list=ls())
library(lme4);library(lmerTest)
library(nlme)
library(boot);library(Rfit)
library(MuMIn);library(ggplot2)
library(grid);library(gridExtra)
library(gtable);library(plyr)
library(dplyr);library(data.table)
library(MuMIn);options(na.action = "na.fail")
library(glmnet);library(glmnetUtils)
library(SoDA);library(spdep);library(spaMM)

## Growth
#FDis effects depends on PC1
coefmean<-summary(mb)$co[,1]
coefSE<-summary(mb)$co[,2]
plot_df<-expand.grid(sqrtFDis=can$sqrtFDis,
                     logPC1=round(c(seq(quantile(can$logPC1,0.05)[[1]],
                                        quantile(can$logPC1,0.95)[[1]],length=4),0),2)) %>%
  mutate(mean=coefmean["(Intercept)"]+coefmean["logPC1"]*logPC1+coefmean["sqrtFDis"]*sqrtFDis+
           coefmean["sqrtFDis:logPC1"]*logPC1*sqrtFDis) %>% 
  mutate(up=coefmean["(Intercept)"]+coefmean["logPC1"]*logPC1+coefmean["sqrtFDis"]*sqrtFDis+
           coefmean["sqrtFDis:logPC1"]*logPC1*sqrtFDis+
           coefSE["(Intercept)"]+coefSE["logPC1"]*logPC1+coefSE["sqrtFDis"]*sqrtFDis+
           coefSE["sqrtFDis:logPC1"]*logPC1*sqrtFDis) %>% 
  mutate(low=coefmean["(Intercept)"]+coefmean["logPC1"]*logPC1+coefmean["sqrtFDis"]*sqrtFDis+
           coefmean["sqrtFDis:logPC1"]*logPC1*sqrtFDis-
           (coefSE["(Intercept)"]+coefSE["logPC1"]*logPC1+coefSE["sqrtFDis"]*sqrtFDis+
              coefSE["sqrtFDis:logPC1"]*logPC1*sqrtFDis)) %>% 
  as.data.table()
plot_df[,":="(sqrtFDis1=sqrtFDis*sd(can$sqrtFDis1)+mean(can$sqrtFDis1),SpPC11=exp(logPC1)*sd(can$SpPC11)+mean(can$SpPC11))] %>% 
  .[,":="(logPC1=as.factor(round(logPC1,2)),SpPC11=as.factor(round(SpPC11,2)))]
head(plot_df);nrow(plot_df)

FD_PC1_Grow<-ggplot(plot_df,aes(y=mean,x=(sqrtFDis1)^2,color=logPC1))+
  theme_classic()+
  geom_ribbon(aes(x=(sqrtFDis1)^2,ymin=low,ymax=up,
                  group=logPC1),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1.1)+
  scale_colour_manual(values=c("maroon4","maroon2","black","lightslateblue","dodgerblue4"),name="",
                      labels=c("-0.83841231"="1.00","-0.4126802475"="2.12","0.013051815"="3.25",
                               "0.4387838775"="4.37","0.86451594"="5.31","0"="Mean"),
                      guide=guide_legend(override.aes = list(colour=NA,fill=NA)))+
  xlab("")+
  ylab(expression(paste("Growth (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x= element_blank(), axis.line.y = element_line(),
        legend.title.align = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))
FD_PC1_Grow<-FD_PC1_Grow+annotate("text",x= 0.15,y=4.3,label="sqrt(FD):~italic(P) <0.001",parse=TRUE,size=3.5)
FD_PC1_Grow<-FD_PC1_Grow+annotate("text",x= 0.15,y=4,label="sqrt(FD)%*%ln(CWMPC1):~italic(P) <0.001",parse=TRUE,size=3.5)
FD_PC1_Grow

summary(mb)$co

## Mortality
#FDis effects depends on PC1
coefmean<-summary(mc)$co[,1]
coefSE<-summary(mc)$co[,2]
plot_df<-expand.grid(sqrtFDis=can$sqrtFDis,
                     sqrtPC1=round(c(seq(quantile(can$sqrtPC1,0.05)[[1]],
                                        quantile(can$sqrtPC1,0.95)[[1]],length=4),0),2)) %>%
  mutate(mean=coefmean["(Intercept)"]+coefmean["sqrtPC1"]*sqrtPC1+coefmean["sqrtFDis"]*sqrtFDis+
           coefmean["sqrtFDis:sqrtPC1"]*sqrtPC1*sqrtFDis) %>% 
  mutate(up=coefmean["(Intercept)"]+coefmean["sqrtPC1"]*sqrtPC1+coefmean["sqrtFDis"]*sqrtFDis+
           coefmean["sqrtFDis:sqrtPC1"]*sqrtPC1*sqrtFDis+
           coefSE["(Intercept)"]+coefSE["sqrtPC1"]*sqrtPC1+coefSE["sqrtFDis"]*sqrtFDis+
           coefSE["sqrtFDis:sqrtPC1"]*sqrtPC1*sqrtFDis) %>% 
  mutate(low=coefmean["(Intercept)"]+coefmean["sqrtPC1"]*sqrtPC1+coefmean["sqrtFDis"]*sqrtFDis+
           coefmean["sqrtFDis:sqrtPC1"]*sqrtPC1*sqrtFDis-
           (coefSE["(Intercept)"]+coefSE["sqrtPC1"]*sqrtPC1+coefSE["sqrtFDis"]*sqrtFDis+
              coefSE["sqrtFDis:sqrtPC1"]*sqrtPC1*sqrtFDis)) %>% 
  as.data.table()
plot_df[,":="(sqrtFDis1=sqrtFDis*sd(can$sqrtFDis1)+mean(can$sqrtFDis1),
              SpPC11=(sqrtPC1)^2*sd(can$SpPC11)+mean(can$SpPC11))] %>% 
  .[,":="(sqrtPC1=as.factor(round(sqrtPC1,2)),SpPC11=as.factor(round(SpPC11,2)))]
head(plot_df);nrow(plot_df)

seq(quantile(can$SpPC11,0.05)[[1]],quantile(can$SpPC11,0.95)[[1]],length=4);mean(can$SpPC11)
FD_PC1_Mort<-ggplot(plot_df,aes(y=mean,x=(sqrtFDis1)^2,color=sqrtPC1))+
  theme_classic()+
  geom_ribbon(aes(x=(sqrtFDis1)^2,ymin=low,ymax=up,
                  group=sqrtPC1),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1.1)+
  scale_colour_manual(values=c("maroon4","maroon2","black","lightslateblue","dodgerblue4"),
                      name=expression(paste(CWM[PC1])),
                      labels=c("-1.7"="-2.5", "-0.65"="-0.5","0.4"="1.6","1.44"="3.6","0"="Mean (0.05)"))+
  xlab("")+
  ylab(expression(paste("Mortality (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x= element_blank(), axis.line.y = element_line())
FD_PC1_Mort<-FD_PC1_Mort+annotate("text",x= 0.15,y=2.8,label="sqrt(FD):~italic(P) <0.001",parse=TRUE,size=3.5)
FD_PC1_Mort<-FD_PC1_Mort+annotate("text",x= 0.15,y=2.6,label="sqrt(FD)%*%ln(CWMPC1):~italic(P) <0.001",parse=TRUE,size=3.5)
FD_PC1_Mort

summary(mc)$co

## Net biomass change
#FDis effects depends on PC1
coefmean<-summary(ma)$co[,1]
coefSE<-summary(ma)$co[,2]
plot_df<-expand.grid(SpFDis=can$SpFDis,
                     logPC1=round(c(seq(quantile(can$logPC1,0.05)[[1]],
                                        quantile(can$logPC1,0.95)[[1]],length=4),0),2)) %>%
  mutate(mean=coefmean["(Intercept)"]+coefmean["logPC1"]*logPC1+coefmean["SpFDis"]*SpFDis+
           coefmean["SpFDis:logPC1"]*logPC1*SpFDis) %>% 
  mutate(up=coefmean["(Intercept)"]+coefmean["logPC1"]*logPC1+coefmean["SpFDis"]*SpFDis+
           coefmean["SpFDis:logPC1"]*logPC1*SpFDis+
           coefSE["(Intercept)"]+coefSE["logPC1"]*logPC1+coefSE["SpFDis"]*SpFDis+
           coefSE["SpFDis:logPC1"]*logPC1*SpFDis) %>% 
  mutate(low=coefmean["(Intercept)"]+coefmean["logPC1"]*logPC1+coefmean["SpFDis"]*SpFDis+
           coefmean["SpFDis:logPC1"]*logPC1*SpFDis-
           (coefSE["(Intercept)"]+coefSE["logPC1"]*logPC1+coefSE["SpFDis"]*SpFDis+
              coefSE["SpFDis:logPC1"]*logPC1*SpFDis)) %>% 
  as.data.table()
plot_df[,":="(SpFDis1=SpFDis*sd(can$SpFDis1)+mean(can$SpFDis1),SpPC11=exp(logPC1)*sd(can$SpPC11)+mean(can$SpPC11))] %>% 
  .[,":="(logPC1=as.factor(round(logPC1,2)),SpPC11=as.factor(round(SpPC11,2)))]
head(plot_df);nrow(plot_df)

FD_PC1_NBC<-ggplot(plot_df,aes(y=mean,x=(SpFDis1),color=logPC1))+
  theme_classic()+
  geom_ribbon(aes(x=(SpFDis1),ymin=low,ymax=up,
                  group=logPC1),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1.1)+
  scale_colour_manual(values=c("maroon4","maroon2","black","lightslateblue","dodgerblue4"),name="",
                      labels=c("-0.83841231"="1.00", "-0.4126802475"="2.12","0.013051815"="3.25",
                               "0.4387838775"="4.37","0.86451594"="5.31","0"="Mean"),
                      guide=guide_legend(override.aes = list(colour=NA,fill=NA)))+
  xlab(expression(paste("Functional diversity (FD)")))+
  ylab(expression(paste("Net biomass change (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.line.y = element_line(),
        legend.title.align = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))
FD_PC1_NBC<-FD_PC1_NBC+annotate("text",x= 0.15,y=2,label="FD:~italic(P) <0.001",parse=TRUE,size=3.5)
FD_PC1_NBC<-FD_PC1_NBC+annotate("text",x= 0.15,y=1.8,label="FD%*%ln(CWMPC1):~italic(P) == 0.034",parse=TRUE,size=3.5)
FD_PC1_NBC

summary(ma)$co

dev.list() # s܂BŁARStudioGD̕\Ȃ΁A̃R[hsĂB
RStudioGD() #@łƂǂɂȂƂ܂B

## Growth
#CMIave effects depends on MATave
coefmean<-summary(mb)$co[,1]
coefSE<-summary(mb)$co[,2]
plot_df<-expand.grid(CMIave=can$CMIave,
                     MATave=round(c(seq(quantile(can$MATave,0.05)[[1]],
                                        quantile(can$MATave,0.95)[[1]],length=4),0),2)) %>%
  mutate(mean=coefmean["(Intercept)"]+coefmean["MATave"]*MATave+coefmean["CMIave"]*CMIave+
           coefmean["CMIave:MATave"]*MATave*CMIave) %>% 
  mutate(up=coefmean["(Intercept)"]+coefmean["MATave"]*MATave+coefmean["CMIave"]*CMIave+
           coefmean["CMIave:MATave"]*MATave*CMIave+
           coefSE["(Intercept)"]+coefSE["MATave"]*MATave+coefSE["CMIave"]*CMIave+
           coefSE["CMIave:MATave"]*MATave*CMIave) %>% 
  mutate(low=coefmean["(Intercept)"]+coefmean["MATave"]*MATave+coefmean["CMIave"]*CMIave+
           coefmean["CMIave:MATave"]*MATave*CMIave-
           (coefSE["(Intercept)"]+coefSE["MATave"]*MATave+coefSE["CMIave"]*CMIave+
              coefSE["CMIave:MATave"]*MATave*CMIave)) %>% 
  as.data.table()
plot_df[,":="(CMIave1=CMIave*sd(can$CMIave1)+mean(can$CMIave1),MATave1=MATave*sd(can$MATave1)+mean(can$MATave1))] %>% 
  .[,":="(MATave=as.factor(round(MATave,2)),MATave1=as.factor(round(MATave1,2)))]
head(plot_df);nrow(plot_df)

CMI_MAT_Grow<-ggplot(plot_df,aes(y=mean,x=(CMIave1),color=MATave))+
  theme_classic()+
  geom_ribbon(aes(x=(CMIave1),ymin=low,ymax=up,
                  group=MATave),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1.1)+
  scale_colour_manual(values=c("violetred3","violet","black","turquoise","turquoise4"),name="",
                      labels=c("-0.83841231"="1.00", "-0.4126802475"="2.12","0.013051815"="3.25",
                               "0.4387838775"="4.37","0.86451594"="5.31","0"="Mean"),
                      guide=guide_legend(override.aes = list(colour=NA,fill=NA)))+
  xlab("")+
  ylab(expression(paste("Growth (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x= element_blank(), axis.line.y = element_line(),
        legend.title.align  = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))
CMI_MAT_Grow<-CMI_MAT_Grow+annotate("text",x= 150,y=7.8,label="CMIave%*%MATave:~italic(P) <0.001",parse=TRUE,size=3.5)
CMI_MAT_Grow

summary(mb)$co

## Mortality
#CMIave effects depends on MATave
coefmean<-summary(mc)$co[,1]
coefSE<-summary(mc)$co[,2]
plot_df<-expand.grid(CMIave=can$CMIave,
                     MATave=round(c(seq(quantile(can$MATave,0.05)[[1]],
                                        quantile(can$MATave,0.95)[[1]],length=4),0),2)) %>%
  mutate(mean=coefmean["(Intercept)"]+coefmean["MATave"]*MATave+coefmean["CMIave"]*CMIave+
           coefmean["CMIave:MATave"]*MATave*CMIave) %>% 
  mutate(up=coefmean["(Intercept)"]+coefmean["MATave"]*MATave+coefmean["CMIave"]*CMIave+
           coefmean["CMIave:MATave"]*MATave*CMIave+
           coefSE["(Intercept)"]+coefSE["MATave"]*MATave+coefSE["CMIave"]*CMIave+
           coefSE["CMIave:MATave"]*MATave*CMIave) %>% 
  mutate(low=coefmean["(Intercept)"]+coefmean["MATave"]*MATave+coefmean["CMIave"]*CMIave+
           coefmean["CMIave:MATave"]*MATave*CMIave-
           (coefSE["(Intercept)"]+coefSE["MATave"]*MATave+coefSE["CMIave"]*CMIave+
              coefSE["CMIave:MATave"]*MATave*CMIave)) %>% 
  as.data.table()
plot_df[,":="(CMIave1=CMIave*sd(can$CMIave1)+mean(can$CMIave1),MATave1=MATave*sd(can$MATave1)+mean(can$MATave1))] %>% 
  .[,":="(MATave=as.factor(round(MATave,2)),MATave1=as.factor(round(MATave1,2)))]
head(plot_df);nrow(plot_df)

CMI_MAT_Mort<-ggplot(plot_df,aes(y=mean,x=(CMIave1),color=MATave))+
  theme_classic()+
  geom_ribbon(aes(x=(CMIave1),ymin=low,ymax=up,
                  group=MATave),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1.1)+
  scale_colour_manual(values=c("violetred3","violet","black","turquoise","turquoise4"),
                      name=expression(paste(MAT[ave], " (",~degree*C,")")),
                      labels=c("-1.66"="-1.6", "-0.58"="1.3","0.5"="4.2","1.58"="7.1","0"="Mean (2.9)"))+
  xlab("")+
  ylab(expression(paste("Mortality (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x= element_blank(), axis.line.y = element_line())
CMI_MAT_Mort<-CMI_MAT_Mort+annotate("text",x= 150,y=3.8,label="CMIave%*%MATave:~italic(P) == 0.007",parse=TRUE,size=3.5)
CMI_MAT_Mort

summary(mc)$co

## Net biomass change
#CMIave effects depends on MATave
coefmean<-summary(ma)$co[,1]
coefSE<-summary(ma)$co[,2]
plot_df<-expand.grid(CMIave=can$CMIave,
                     MATave=round(c(seq(quantile(can$MATave,0.05)[[1]],
                                        quantile(can$MATave,0.95)[[1]],length=4),0),2)) %>%
  mutate(mean=coefmean["(Intercept)"]+coefmean["MATave"]*MATave+coefmean["CMIave"]*CMIave+
           coefmean["CMIave:MATave"]*MATave*CMIave) %>% 
  mutate(up=coefmean["(Intercept)"]+coefmean["MATave"]*MATave+coefmean["CMIave"]*CMIave+
           coefmean["CMIave:MATave"]*MATave*CMIave+
           coefSE["(Intercept)"]+coefSE["MATave"]*MATave+coefSE["CMIave"]*CMIave+
           coefSE["CMIave:MATave"]*MATave*CMIave) %>% 
  mutate(low=coefmean["(Intercept)"]+coefmean["MATave"]*MATave+coefmean["CMIave"]*CMIave+
           coefmean["CMIave:MATave"]*MATave*CMIave-
           (coefSE["(Intercept)"]+coefSE["MATave"]*MATave+coefSE["CMIave"]*CMIave+
              coefSE["CMIave:MATave"]*MATave*CMIave)) %>% 
  as.data.table()
plot_df[,":="(CMIave1=CMIave*sd(can$CMIave1)+mean(can$CMIave1),MATave1=MATave*sd(can$MATave1)+mean(can$MATave1))] %>% 
  .[,":="(MATave=as.factor(round(MATave,2)),MATave1=as.factor(round(MATave1,2)))]
head(plot_df);nrow(plot_df)

CMI_MAT_NBC<-ggplot(plot_df,aes(y=mean,x=(CMIave1),color=MATave))+
  theme_classic()+
  geom_ribbon(aes(x=(CMIave1),ymin=low,ymax=up,
                  group=MATave),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1.1)+
  scale_colour_manual(values=c("violetred3","violet","black","turquoise","turquoise4"),name="",
                      labels=c("-0.83841231"="1.00", "-0.4126802475"="2.12","0.013051815"="3.25",
                               "0.4387838775"="4.37","0.86451594"="5.31","0"="Mean"),
                      guide=guide_legend(override.aes = list(colour=NA,fill=NA)))+
  xlab(expression(paste(CMI[ave]," (cm)")))+
  ylab(expression(paste("Net biomass change (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.line.y = element_line(),
        legend.title.align = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))
CMI_MAT_NBC<-CMI_MAT_NBC+annotate("text",x= 150,y=6,label="CMIave%*%MATave:~italic(P) == '0.110'",parse=TRUE,size=3.5)
CMI_MAT_NBC

summary(ma)$co

#### Bind figures ####
rbind_gtable_max <- function(...){
  gtl <- list(...)
  stopifnot(all(sapply(gtl, is.gtable)))
  bind2 <- function (x, y) 
  {
    stopifnot(ncol(x) == ncol(y))
    if (nrow(x) == 0) 
      return(y)
    if (nrow(y) == 0) 
      return(x)
    y$layout$t <- y$layout$t + nrow(x)
    y$layout$b <- y$layout$b + nrow(x)
    x$layout <- rbind(x$layout, y$layout)
    x$heights <- gtable:::insert.unit(x$heights, y$heights)
    x$rownames <- c(x$rownames, y$rownames)
    x$widths <- grid::unit.pmax(x$widths, y$widths)
    x$grobs <- append(x$grobs, y$grobs)
    x
  }
  
  Reduce(bind2, gtl)
}

f1 <- ggplotGrob(CMI_MAT_Grow)
f2 <- ggplotGrob(CMI_MAT_Mort)
f3 <- ggplotGrob(CMI_MAT_NBC)

maxWidth = unit.pmax(g1$widths[2:3], g2$widths[2:3], g3$widths[2:3])
f1$widths[2:3] <- maxWidth
f2$widths[2:3] <- maxWidth
f3$widths[2:3] <- maxWidth

g1 <- ggplotGrob(FD_PC1_Grow)
g2 <- ggplotGrob(FD_PC1_Mort)
g3 <- ggplotGrob(FD_PC1_NBC)

maxWidth = unit.pmax(g1$widths[2:3], g2$widths[2:3], g3$widths[2:3])
g1$widths[2:3] <- maxWidth
g2$widths[2:3] <- maxWidth
g3$widths[2:3] <- maxWidth

tiff("FigS_CMIave_by_MATave_FDis_by_PC1.tiff",width=2500,height=3000,res=300,compression="lzw")
grid.draw(cbind(rbind(f1,f2,f3,size="last"),rbind(g1,g2,g3,size="last"),size="first"))
grid.text("(a)",x=unit(0.02,"npc"),y=unit(0.993,"npc"),gp=gpar(fontsize=14,font=2))
grid.text("(b)",x=unit(0.52,"npc"),y=unit(0.993,"npc"),gp=gpar(fontsize=14,font=2))

dev.off()
