library(nlme);library(lmeresampler)
library(lme4);library(lmerTest)
library(boot);library(Rfit)
library(MuMIn);library(ggplot2)
library(grid);library(gridExtra)
library(gtable);library(plyr)
library(dplyr);library(data.table)
library(MuMIn);options(na.action = "na.fail")
library(glmnet);library(glmnetUtils)
library(Hmisc)
library(spdep);library(SoDA);library(ape)
library(spaMM)
library(fastDummies)

################################## Grow ################################## 
glmnet.dat<-can[,.(Intercept=1,
                   PS=sqrtPS,logSA=logSA,CMIave=CMIave,MATave=MATave,FDis=sqrtFDis,PC1=logPC1,
                   SA_FDis=logSA*sqrtFDis,SA_PC1=logSA*logPC1,SA_CMIave=logSA*CMIave,SA_MATave=logSA*MATave,
                   CMIave_MATave=CMIave*MATave,FDis_PC1=sqrtFDis*logPC1,
                   CMIave_FDis=CMIave*sqrtFDis,MATave_FDis=MATave*sqrtFDis,
                   CMIave_PC1=CMIave*logPC1,MATave_PC1=MATave*logPC1)]#data table for ridge regression
glmnet.dat<-as.data.table(scale(glmnet.dat))##scale everything
glmnet.dat[,":="(AGBGI=can$AGBGI,PLOT_ID=as.factor(can$PLOT_ID),
                 Prov=as.factor(can$Prov))]#Add these after scaling

mb_sc<-lmer(AGBGI~PS+logSA+CMIave+MATave+FDis+PC1+
              SA_FDis+SA_PC1+SA_CMIave+SA_MATave+
              CMIave_MATave+FDis_PC1+
              CMIave_FDis+MATave_FDis+
              CMIave_PC1+MATave_PC1+
              (1|PLOT_ID)+(1|Prov),glmnet.dat)
#mixed.bootmb_sc<-bootMer(mb_sc,function(.)fixef(.),nsim=1000)
#save(mixed.bootmb_sc,file="mixed.bootmb_sc.R")
load("mixed.bootmb_sc.R")
#Note that this does not show exactly identical coef estimates because the interactions were scaled again after multiplying
#Directionality and significance are consitent with the main model: this scales were needed to allow comparison the models among here (ridge, NP)

glmnet.dat[,":="(ran1=ranef(mb_sc)$PLOT_ID[match(glmnet.dat$PLOT_ID,row.names(ranef(mb_sc)$PLOT_ID)),],
                 ran2=ranef(mb_sc)$Prov[match(glmnet.dat$Prov,row.names(ranef(mb_sc)$Prov)),])]

glmnet.dat[,AGBGI_corr:=AGBGI-ran1-ran2]##remove the effects of PLOT_ID, Prov
summary(lm(AGBGI_corr~PS+logSA+CMIave+MATave+FDis+PC1+
             SA_FDis+SA_PC1+SA_CMIave+SA_MATave+
             CMIave_MATave+FDis_PC1+
             CMIave_FDis+MATave_FDis+
             CMIave_PC1+MATave_PC1,glmnet.dat))$coef
summary(mb_sc)$coef#comparable

## Ridge
lambda_values=summary(sapply(1:100,function(i)cv.glmnet(
  x=as.matrix(glmnet.dat[,.(PS,logSA,CMIave,MATave,FDis,PC1,
                            SA_FDis,SA_PC1,SA_CMIave,SA_MATave,
                            CMIave_MATave,FDis_PC1,
                            CMIave_FDis,MATave_FDis,
                            CMIave_PC1,MATave_PC1)]),
  y=as.matrix(glmnet.dat[,AGBGI_corr])#,weights=as.vector(glmnet.dat[,wi])
)$lambda.1se))

lambda_values=seq(max(lambda_values),min(lambda_values),length=100)

Grow.gl<-glmnet(AGBGI_corr~PS+logSA+CMIave+MATave+FDis+PC1+
                  SA_FDis+SA_PC1+SA_CMIave+SA_MATave+
                  CMIave_MATave+FDis_PC1+
                  CMIave_FDis+MATave_FDis+
                  CMIave_PC1+MATave_PC1,
                #weights=wi,
                data=glmnet.dat,
                lambda=lambda_values,#covers range of no suppression to max of 1se
                alpha=0)#0=ridge regression

#bootstrap [lambda=1se]
coeff.se<-ldply(1:1000, function(i){
  too_boot<-sample(unique(glmnet.dat[,PLOT_ID]),replace=TRUE)
  newdat<-glmnet.dat[PLOT_ID%in%too_boot]
  newdat[,":="(Prov=glmnet.dat[match(newdat$PLOT_ID,PLOT_ID),Prov])]
  
  lmerboot<-(lmer(AGBGI~PS+logSA+CMIave+MATave+FDis+PC1+
                    SA_FDis+SA_PC1+SA_CMIave+SA_MATave+
                    CMIave_MATave+FDis_PC1+
                    CMIave_FDis+MATave_FDis+
                    CMIave_PC1+MATave_PC1+
                    (1|PLOT_ID)+(1|Prov),
                  #weights=wi,
                  data=newdat))
  
  newdat[,":="(ran1=ranef(lmerboot)$PLOT_ID[match(newdat$PLOT_ID,row.names(ranef(lmerboot)$PLOT_ID)),],
               ran2=ranef(lmerboot)$Prov[match(newdat$Prov,row.names(ranef(lmerboot)$Prov)),])]
  
  newdat[,AGBGI_corr:=AGBGI-ran1-ran2]
  
  Grow.gl2<-glmnet(AGBGI_corr~PS+logSA+CMIave+MATave+FDis+PC1+
                     SA_FDis+SA_PC1+SA_CMIave+SA_MATave+
                     CMIave_MATave+FDis_PC1+
                     CMIave_FDis+MATave_FDis+
                     CMIave_PC1+MATave_PC1,
                   #weights=wi,
                   data=newdat,
                   lambda=lambda_values,
                   alpha=0)
  coef(Grow.gl2)@x},.progress="win"
)%>%as.data.table

#fwrite(coeff.se,"Ridge_regression_coeff.1se.Grow.csv")
coeff.se<-fread("Ridge_regression_coeff.1se.Grow.csv")

colnames(coeff.se)<-rep(c("Int","PS","logSA","CMIave","MATave","FDis","PC1",
                          "SA_FDis","SA_PC1","SA_CMIave","SA_MATave",
                          "CMIave_MATave","FDis_PC1",
                          "CMIave_FDis","MATave_FDis",
                          "CMIave_PC1","MATave_PC1"),
                        ncol(coeff.se)/17)

coeff.se_tidy<-data.table(Int=unlist(apply(coeff.se[,grep("Int",colnames(coeff.se)),with=FALSE],2,list)),
                          PS=unlist(apply(coeff.se[,grep("PS",colnames(coeff.se)),with=FALSE],2,list)),
                          logSA=unlist(apply(coeff.se[,grep("logSA",colnames(coeff.se)),with=FALSE],2,list)),
                          CMIave=unlist(apply(coeff.se[,grep("^CMIave$",colnames(coeff.se)),with=FALSE],2,list)),
                          MATave=unlist(apply(coeff.se[,grep("^MATave$",colnames(coeff.se)),with=FALSE],2,list)),
                          FDis=unlist(apply(coeff.se[,grep("^FDis$",colnames(coeff.se)),with=FALSE],2,list)),
                          PC1=unlist(apply(coeff.se[,grep("^PC1$",colnames(coeff.se)),with=FALSE],2,list)),
                          SA_FDis=unlist(apply(coeff.se[,grep("^SA_FDis$",colnames(coeff.se)),with=FALSE],2,list)),
                          SA_PC1=unlist(apply(coeff.se[,grep("^SA_PC1$",colnames(coeff.se)),with=FALSE],2,list)),
                          SA_CMIave=unlist(apply(coeff.se[,grep("^SA_CMIave$",colnames(coeff.se)),with=FALSE],2,list)),
                          SA_MATave=unlist(apply(coeff.se[,grep("^SA_MATave$",colnames(coeff.se)),with=FALSE],2,list)),
                          CMIave_MATave=unlist(apply(coeff.se[,grep("^CMIave_MATave$",colnames(coeff.se)),with=FALSE],2,list)),
                          FDis_PC1=unlist(apply(coeff.se[,grep("^FDis_PC1$",colnames(coeff.se)),with=FALSE],2,list)),
                          CMIave_FDis=unlist(apply(coeff.se[,grep("^CMIave_FDis$",colnames(coeff.se)),with=FALSE],2,list)),
                          MATave_FDis=unlist(apply(coeff.se[,grep("^MATave_FDis$",colnames(coeff.se)),with=FALSE],2,list)),
                          CMIave_PC1=unlist(apply(coeff.se[,grep("^CMIave_PC1$",colnames(coeff.se)),with=FALSE],2,list)),
                          MATave_PC1=unlist(apply(coeff.se[,grep("^MATave_PC1$",colnames(coeff.se)),with=FALSE],2,list)))

GrowT_1se<-data.table(Source=c("Int","PS","logSA","CMIave","MATave","FDis","PC1",
                               "SA_FDis","SA_PC1","SA_CMIave","SA_MATave",
                               "CMIave_MATave","FDis_PC1",
                               "CMIave_FDis","MATave_FDis",
                               "CMIave_PC1","MATave_PC1"),
                      mean.Grow=NA,up.Grow=NA,low.Grow=NA)

GrowT_1se$mean.Grow<-apply(coeff.se_tidy,2,mean)
GrowT_1se$up.Grow<-apply(coeff.se_tidy,2,function(x){quantile(x,0.975)})
GrowT_1se$low.Grow<-apply(coeff.se_tidy,2,function(x){quantile(x,0.025)})

## Multi Linear mixed effects (bootstrap) ##
GrowT_multi<-data.table(Source=c("Int","PS","logSA","CMIave","MATave","FDis","PC1",
                                 "SA_FDis","SA_PC1","SA_CMIave","SA_MATave",
                                 "CMIave_MATave","FDis_PC1",
                                 "CMIave_FDis","MATave_FDis",
                                 "CMIave_PC1","MATave_PC1"),
                        mean.Grow=NA,up.Grow=NA,low.Grow=NA)

GrowT_multi$mean.Grow<-fixef(mb_sc)
GrowT_multi$up.Grow<-apply(mixed.bootmb_sc$t,2,function(x){quantile(x,0.975)})
GrowT_multi$low.Grow<-apply(mixed.bootmb_sc$t,2,function(x){quantile(x,0.025)})

#nonpara
nmb_sc<-rfit(AGBGI_corr~
               PS+logSA+CMIave+MATave+FDis+PC1+
               SA_FDis+SA_PC1+SA_CMIave+SA_MATave+
               CMIave_MATave+FDis_PC1+
               CMIave_FDis+MATave_FDis+
               CMIave_PC1+MATave_PC1,
             data=glmnet.dat)
summary(nmb_sc)$co

GrowT_multi_NP<-data.table(Source=c("Int","PS","logSA","CMIave","MATave","FDis","PC1",
                                    "SA_FDis","SA_PC1","SA_CMIave","SA_MATave",
                                    "CMIave_MATave","FDis_PC1",
                                    "CMIave_FDis","MATave_FDis",
                                    "CMIave_PC1","MATave_PC1"),
                           mean.Grow=NA,up.Grow=NA,low.Grow=NA)

GrowT_multi_NP$mean.Grow<-summary(nmb_sc)$co[,1]
GrowT_multi_NP$up.Grow<-summary(nmb_sc)$co[,1]+summary(nmb_sc)$co[,2]
GrowT_multi_NP$low.Grow<-summary(nmb_sc)$co[,1]-summary(nmb_sc)$co[,2]

## CMIave Linear mixed effects (bootstrap) ##
GrowT_CMIave<-data.table(Source=c("Int","PS","logSA","CMIave","FDis","PC1",
                                  "SA_FDis","SA_PC1","SA_CMIave",
                                  "FDis_PC1",
                                  "CMIave_FDis",
                                  "CMIave_PC1"),
                         mean.Grow=NA,up.Grow=NA,low.Grow=NA)

mbCMIave_sc<-lmer(AGBGI~
                    PS+logSA+CMIave+FDis+PC1+
                    SA_FDis+SA_PC1+SA_CMIave+
                    FDis_PC1+CMIave_FDis+CMIave_PC1+
                    (1|PLOT_ID)+(1|Prov),glmnet.dat)
#mixed.bootmb_CMIave_sc<-bootMer(mbCMIave_sc,function(.)fixef(.),nsim=1000)
#save(mixed.bootmb_CMIave_sc,file="mixed.bootmb_CMIave_sc.R")
load("mixed.bootmb_CMIave_sc.R")

GrowT_CMIave$mean.Grow<-fixef(mbCMIave_sc)
GrowT_CMIave$up.Grow<-apply(mixed.bootmb_CMIave_sc$t,2,function(x){quantile(x,0.975)})
GrowT_CMIave$low.Grow<-apply(mixed.bootmb_CMIave_sc$t,2,function(x){quantile(x,0.025)})

## MATave Linear mixed effects (bootstrap) ##
GrowT_MATave<-data.table(Source=c("Int","PS","logSA","MATave","FDis","PC1",
                                  "SA_FDis","SA_PC1","SA_MATave",
                                  "FDis_PC1",
                                  "MATave_FDis",
                                  "MATave_PC1"),
                         mean.Grow=NA,up.Grow=NA,low.Grow=NA)

mbMATave_sc<-lmer(AGBGI~
                    PS+logSA+MATave+FDis+PC1+
                    SA_FDis+SA_PC1+SA_MATave+
                    FDis_PC1+MATave_FDis+MATave_PC1+
                    (1|PLOT_ID)+(1|Prov),glmnet.dat)
#mixed.bootmb_MATave_sc<-bootMer(mbMATave_sc,function(.)fixef(.),nsim=1000)
#save(mixed.bootmb_MATave_sc,file="mixed.bootmb_MATave_sc.R")
load("mixed.bootmb_MATave_sc.R")

GrowT_MATave$mean.Grow<-fixef(mbMATave_sc)
GrowT_MATave$up.Grow<-apply(mixed.bootmb_MATave_sc$t,2,function(x){quantile(x,0.975)})
GrowT_MATave$low.Grow<-apply(mixed.bootmb_MATave_sc$t,2,function(x){quantile(x,0.025)})

#Bind
GrowT_multi$model<-"Linear mixed effects (modelled with CMIave and MAT simultaneously)"
GrowT_1se$model<-"Ridge regression (modelled with CMIave and MAT simultaneously)"
GrowT_multi_NP$model<-"Nonparametric (modelled with CMIave and MAT simultaneously)"
GrowT_CMIave$model<-"Linear mixed effects (modelled with CMIave)"
GrowT_MATave$model<-"Linear mixed effects (modelled with MATave)"

to_gg<-rbind(GrowT_multi,GrowT_1se,GrowT_multi_NP,GrowT_CMIave,GrowT_MATave)
to_gg$model<-factor(to_gg$model,levels=c("Linear mixed effects (modelled with CMIave and MAT simultaneously)",
                                         "Ridge regression (modelled with CMIave and MAT simultaneously)",
                                         "Nonparametric (modelled with CMIave and MAT simultaneously)",
                                         "Linear mixed effects (modelled with CMIave)",
                                         "Linear mixed effects (modelled with MATave)"))
to_gg[Source=="PS",Source:="f(PS)"];to_gg[Source=="logSA",Source:="f(SA)"]
to_gg[Source=="FDis",Source:="f(FD)"];to_gg[Source=="PC1",Source:="f(CWM)"]
to_gg[Source=="SA_FDis",Source:="f(SA)*f(FD)"];to_gg[Source=="SA_PC1",Source:="f(SA)*f(CWM)"]
to_gg[Source=="SA_CMIave",Source:="f(SA)*CMIave"];to_gg[Source=="SA_MATave",Source:="f(SA)*MATave"]
to_gg[Source=="CMIave_MATave",Source:="CMIave*MATave"];to_gg[Source=="FDis_PC1",Source:="f(FD)*f(CWM)"]
to_gg[Source=="CMIave_FDis",Source:="CMIave*f(FD)"];to_gg[Source=="MATave_FDis",Source:="MATave*f(FD)"]
to_gg[Source=="CMIave_PC1",Source:="CMIave*f(CWM)"];to_gg[Source=="MATave_PC1",Source:="MATave*f(CWM)"]
to_gg$Source<-as.factor(to_gg$Source)
to_gg$Source<-factor(to_gg$Source,levels=c("Int","f(PS)","f(SA)","CMIave","MATave","f(FD)","f(CWM)",
                                           "f(SA)*f(FD)","f(SA)*f(CWM)",
                                           "f(SA)*CMIave","f(SA)*MATave",
                                           "CMIave*MATave","f(FD)*f(CWM)",
                                           "CMIave*f(FD)","MATave*f(FD)",
                                           "CMIave*f(CWM)","MATave*f(CWM)"))

Grow<-ggplot(to_gg[to_gg$Source!="Int"],aes(x=Source,y=mean.Grow,ymin=low.Grow,ymax=up.Grow,col=model))+
  geom_point(position=position_dodge(0.4))+
  geom_errorbar(position=position_dodge(0.4),width=0.3)+
  theme_classic()+
  geom_hline(aes(yintercept=0),linetype="dotted")+
  scale_color_discrete(name="Model")+
  theme(legend.position=c(0.7,0.8),
        legend.background = element_rect(fill="aliceblue",colour=NA,size=0.2),
        axis.text.x=element_text(angle=30,vjust=0.5,size=12),
        axis.text.y=element_text(size=12))+
  ylab("Coefficient estimate")+xlab("")#+
#guides(col=FALSE)
Grow

################################## Mort ################################## 
glmnet.dat<-can[,.(Intercept=1,PS=PS,logSA=logSA,CMIave=CMIave,MATave=MATave,FDis=sqrtFDis,PC1=sqrtPC1,
                   SA_FDis=logSA*sqrtFDis,SA_PC1=logSA*sqrtPC1,SA_CMIave=logSA*CMIave,SA_MATave=logSA*MATave,
                   CMIave_MATave=CMIave*MATave,FDis_PC1=sqrtFDis*sqrtPC1,
                   CMIave_FDis=CMIave*sqrtFDis,MATave_FDis=MATave*sqrtFDis,
                   CMIave_PC1=CMIave*sqrtPC1,MATave_PC1=MATave*sqrtPC1)]#data table for ridge regression
glmnet.dat<-as.data.table(scale(glmnet.dat))##scale everything
glmnet.dat[,":="(AGBM=can$AGBM,PLOT_ID=as.factor(can$PLOT_ID),
                 Prov=as.factor(can$Prov))]#Add these after scaling

mc_sc<-lmer(AGBM~
              PS+logSA+CMIave+MATave+FDis+PC1+
              SA_FDis+SA_PC1+SA_CMIave+SA_MATave+
              CMIave_MATave+FDis_PC1+
              CMIave_FDis+MATave_FDis+
              CMIave_PC1+MATave_PC1+
              (1|PLOT_ID)+(1|Prov),glmnet.dat)
#mixed.bootmc_sc<-bootMer(mc_sc,function(.)fixef(.),nsim=1000)
#save(mixed.bootmc_sc,file="mixed.bootmc_sc.R")
load("mixed.bootmc_sc.R")

glmnet.dat[,":="(ran1=ranef(mc_sc)$PLOT_ID[match(glmnet.dat$PLOT_ID,row.names(ranef(mc_sc)$PLOT_ID)),],
                 ran2=ranef(mc_sc)$Prov[match(glmnet.dat$Prov,row.names(ranef(mc_sc)$Prov)),])]

glmnet.dat[,AGBM_corr:=AGBM-ran1-ran2]##remove the effects of PLOT_ID, Eco, Prov
summary(lm(AGBM_corr~
             PS+logSA+CMIave+MATave+FDis+PC1+
             SA_FDis+SA_PC1+SA_CMIave+SA_MATave+
             CMIave_MATave+FDis_PC1+
             CMIave_FDis+MATave_FDis+
             CMIave_PC1+MATave_PC1,glmnet.dat))$coef
summary(mc_sc)$coef#comparable

lambda_values=summary(sapply(1:100,function(i)cv.glmnet(
  x=as.matrix(glmnet.dat[,.(PS+logSA,CMIave,MATave,FDis,PC1,
                            SA_FDis,SA_PC1,SA_CMIave,SA_MATave,
                            CMIave_MATave,FDis_PC1,
                            CMIave_FDis,MATave_FDis,
                            CMIave_PC1,MATave_PC1)]),
  y=as.matrix(glmnet.dat[,AGBM_corr])#,weights=as.vector(glmnet.dat[,wi])
)$lambda.1se))

lambda_values=seq(max(lambda_values),min(lambda_values),length=100)

Mort.gl<-glmnet(AGBM_corr~
                  PS+logSA+CMIave+MATave+FDis+PC1+
                  SA_FDis+SA_PC1+SA_CMIave+SA_MATave+
                  CMIave_MATave+FDis_PC1+
                  CMIave_FDis+MATave_FDis+
                  CMIave_PC1+MATave_PC1,
                data=glmnet.dat,
                lambda=lambda_values,#covers range of no suppression to max of 1se
                alpha=0)#0=ridge regression

#bootstrap [lambda=1se]
coeff.se<-ldply(1:1000, function(i){
  too_boot<-sample(unique(glmnet.dat[,PLOT_ID]),replace=TRUE)
  newdat<-glmnet.dat[PLOT_ID%in%too_boot]
  newdat[,":="(Prov=glmnet.dat[match(newdat$PLOT_ID,PLOT_ID),Prov])]
  
  lmerboot<-(lmer(AGBM~PS+logSA+CMIave+MATave+FDis+PC1+
                    SA_FDis+SA_PC1+SA_CMIave+SA_MATave+
                    CMIave_MATave+FDis_PC1+
                    CMIave_FDis+MATave_FDis+
                    CMIave_PC1+MATave_PC1+
                    (1|PLOT_ID)+(1|Prov),
                  #weights=wi,
                  data=newdat))
  
  newdat[,":="(ran1=ranef(lmerboot)$PLOT_ID[match(newdat$PLOT_ID,row.names(ranef(lmerboot)$PLOT_ID)),],
               ran2=ranef(lmerboot)$Prov[match(newdat$Prov,row.names(ranef(lmerboot)$Prov)),])]
  
  newdat[,AGBM_corr:=AGBM-ran1-ran2]
  
  Mort.gl2<-glmnet(AGBM_corr~PS+logSA+CMIave+MATave+FDis+PC1+
                     SA_FDis+SA_PC1+SA_CMIave+SA_MATave+
                     CMIave_MATave+FDis_PC1+
                     CMIave_FDis+MATave_FDis+
                     CMIave_PC1+MATave_PC1,
                   data=newdat,
                   lambda=lambda_values,
                   alpha=0)
  coef(Mort.gl2)@x},.progress="win"
)%>%as.data.table

#fwrite(coeff.se,"Ridge_regression_coeff.1se.Mort.csv")
coeff.se<-fread("Ridge_regression_coeff.1se.Mort.csv")

colnames(coeff.se)<-rep(c("Int","PS","logSA","CMIave","MATave","FDis","PC1",
                          "SA_FDis","SA_PC1","SA_CMIave","SA_MATave",
                          "CMIave_MATave","FDis_PC1",
                          "CMIave_FDis","MATave_FDis",
                          "CMIave_PC1","MATave_PC1"),
                        ncol(coeff.se)/17)

coeff.se_tidy<-data.table(Int=unlist(apply(coeff.se[,grep("Int",colnames(coeff.se)),with=FALSE],2,list)),
                          PS=unlist(apply(coeff.se[,grep("PS",colnames(coeff.se)),with=FALSE],2,list)),
                          logSA=unlist(apply(coeff.se[,grep("logSA",colnames(coeff.se)),with=FALSE],2,list)),
                          CMIave=unlist(apply(coeff.se[,grep("^CMIave$",colnames(coeff.se)),with=FALSE],2,list)),
                          MATave=unlist(apply(coeff.se[,grep("^MATave$",colnames(coeff.se)),with=FALSE],2,list)),
                          FDis=unlist(apply(coeff.se[,grep("^FDis$",colnames(coeff.se)),with=FALSE],2,list)),
                          PC1=unlist(apply(coeff.se[,grep("^PC1$",colnames(coeff.se)),with=FALSE],2,list)),
                          SA_FDis=unlist(apply(coeff.se[,grep("^SA_FDis$",colnames(coeff.se)),with=FALSE],2,list)),
                          SA_PC1=unlist(apply(coeff.se[,grep("^SA_PC1$",colnames(coeff.se)),with=FALSE],2,list)),
                          SA_CMIave=unlist(apply(coeff.se[,grep("^SA_CMIave$",colnames(coeff.se)),with=FALSE],2,list)),
                          SA_MATave=unlist(apply(coeff.se[,grep("^SA_MATave$",colnames(coeff.se)),with=FALSE],2,list)),
                          CMIave_MATave=unlist(apply(coeff.se[,grep("^CMIave_MATave$",colnames(coeff.se)),with=FALSE],2,list)),
                          FDis_PC1=unlist(apply(coeff.se[,grep("^FDis_PC1$",colnames(coeff.se)),with=FALSE],2,list)),
                          CMIave_FDis=unlist(apply(coeff.se[,grep("^CMIave_FDis$",colnames(coeff.se)),with=FALSE],2,list)),
                          MATave_FDis=unlist(apply(coeff.se[,grep("^MATave_FDis$",colnames(coeff.se)),with=FALSE],2,list)),
                          CMIave_PC1=unlist(apply(coeff.se[,grep("^CMIave_PC1$",colnames(coeff.se)),with=FALSE],2,list)),
                          MATave_PC1=unlist(apply(coeff.se[,grep("^MATave_PC1$",colnames(coeff.se)),with=FALSE],2,list)))

MortT_1se<-data.table(Source=c("Int","PS","logSA","CMIave","MATave","FDis","PC1",
                               "SA_FDis","SA_PC1","SA_CMIave","SA_MATave",
                               "CMIave_MATave","FDis_PC1",
                               "CMIave_FDis","MATave_FDis",
                               "CMIave_PC1","MATave_PC1"),
                      mean.Mort=NA,up.Mort=NA,low.Mort=NA)

MortT_1se$mean.Mort<-apply(coeff.se_tidy,2,mean)
MortT_1se$up.Mort<-apply(coeff.se_tidy,2,function(x){quantile(x,0.975)})
MortT_1se$low.Mort<-apply(coeff.se_tidy,2,function(x){quantile(x,0.025)})

## Multi Linear mixed effects (bootstrap) ##
MortT_multi<-data.table(Source=c("Int","PS","logSA","CMIave","MATave","FDis","PC1",
                                 "SA_FDis","SA_PC1","SA_CMIave","SA_MATave",
                                 "CMIave_MATave","FDis_PC1",
                                 "CMIave_FDis","MATave_FDis",
                                 "CMIave_PC1","MATave_PC1"),
                        mean.Mort=NA,up.Mort=NA,low.Mort=NA)

MortT_multi$mean.Mort<-fixef(mc_sc)
MortT_multi$up.Mort<-apply(mixed.bootmc_sc$t,2,function(x){quantile(x,0.975)})
MortT_multi$low.Mort<-apply(mixed.bootmc_sc$t,2,function(x){quantile(x,0.025)})

#nonpara
nmc_sc<-rfit(AGBM~PS+logSA+CMIave+MATave+FDis+PC1+
               SA_FDis+SA_PC1+SA_CMIave+SA_MATave+
               CMIave_MATave+FDis_PC1+
               CMIave_FDis+MATave_FDis+
               CMIave_PC1+MATave_PC1,
             data=glmnet.dat)
summary(nmc_sc)$co

MortT_multi_NP<-data.table(Source=c("Int","PS","logSA","CMIave","MATave","FDis","PC1",
                                    "SA_FDis","SA_PC1","SA_CMIave","SA_MATave",
                                    "CMIave_MATave","FDis_PC1",
                                    "CMIave_FDis","MATave_FDis",
                                    "CMIave_PC1","MATave_PC1"),
                           mean.Mort=NA,up.Mort=NA,low.Mort=NA)

MortT_multi_NP$mean.Mort<-summary(nmc_sc)$co[,1]
MortT_multi_NP$up.Mort<-summary(nmc_sc)$co[,1]+summary(nmc_sc)$co[,2]
MortT_multi_NP$low.Mort<-summary(nmc_sc)$co[,1]-summary(nmc_sc)$co[,2]

## CMIave Linear mixed effects (bootstrap) ##
MortT_CMIave<-data.table(Source=c("Int","PS","logSA","CMIave","FDis","PC1",
                                  "SA_FDis","SA_PC1","SA_CMIave",
                                  "FDis_PC1",
                                  "CMIave_FDis",
                                  "CMIave_PC1"),
                         mean.Mort=NA,up.Mort=NA,low.Mort=NA)

mcCMIave_sc<-lmer(AGBM~PS+logSA+CMIave+FDis+PC1+
                    SA_FDis+SA_PC1+SA_CMIave+
                    FDis_PC1+CMIave_FDis+CMIave_PC1+
                    (1|PLOT_ID)+(1|Prov),glmnet.dat)
#mixed.bootmc_CMIave_sc<-bootMer(mcCMIave_sc,function(.)fixef(.),nsim=1000)
#save(mixed.bootmc_CMIave_sc,file="mixed.bootmc_CMIave_sc.R")
load("mixed.bootmc_CMIave_sc.R")

MortT_CMIave$mean.Mort<-fixef(mcCMIave_sc)
MortT_CMIave$up.Mort<-apply(mixed.bootmc_CMIave_sc$t,2,function(x){quantile(x,0.975)})
MortT_CMIave$low.Mort<-apply(mixed.bootmc_CMIave_sc$t,2,function(x){quantile(x,0.025)})

## MATave Linear mixed effects (bootstrap) ##
MortT_MATave<-data.table(Source=c("Int","PS","logSA","MATave","FDis","PC1",
                                  "SA_FDis","SA_PC1","SA_MATave",
                                  "FDis_PC1",
                                  "MATave_FDis",
                                  "MATave_PC1"),
                         mean.Mort=NA,up.Mort=NA,low.Mort=NA)

mcMATave_sc<-lmer(AGBM~PS+logSA+MATave+FDis+PC1+
                    SA_FDis+SA_PC1+SA_MATave+
                    FDis_PC1+MATave_FDis+MATave_PC1+
                    (1|PLOT_ID)+(1|Prov),glmnet.dat)
#mixed.bootmc_MATave_sc<-bootMer(mcMATave_sc,function(.)fixef(.),nsim=1000)
#save(mixed.bootmc_MATave_sc,file="mixed.bootmc_MATave_sc.R")
load("mixed.bootmc_MATave_sc.R")

MortT_MATave$mean.Mort<-fixef(mcMATave_sc)
MortT_MATave$up.Mort<-apply(mixed.bootmc_MATave_sc$t,2,function(x){quantile(x,0.975)})
MortT_MATave$low.Mort<-apply(mixed.bootmc_MATave_sc$t,2,function(x){quantile(x,0.025)})

#Bind
MortT_multi$model<-"Linear mixed effects (modelled with CMIave and MAT simultaneously)"
MortT_1se$model<-"Ridge regression (modelled with CMIave and MAT simultaneously)"
MortT_multi_NP$model<-"Nonparametric (modelled with CMIave and MAT simultaneously)"
MortT_CMIave$model<-"Linear mixed effects (modelled with CMIave)"
MortT_MATave$model<-"Linear mixed effects (modelled with MATave)"

to_gg<-rbind(MortT_multi,MortT_1se,MortT_multi_NP,MortT_CMIave,MortT_MATave)
to_gg$model<-factor(to_gg$model,levels=c("Linear mixed effects (modelled with CMIave and MAT simultaneously)",
                                         "Ridge regression (modelled with CMIave and MAT simultaneously)",
                                         "Nonparametric (modelled with CMIave and MAT simultaneously)",
                                         "Linear mixed effects (modelled with CMIave)",
                                         "Linear mixed effects (modelled with MATave)"))
to_gg[Source=="PS",Source:="f(PS)"];to_gg[Source=="logSA",Source:="f(SA)"]
to_gg[Source=="FDis",Source:="f(FD)"];to_gg[Source=="PC1",Source:="f(CWM)"]
to_gg[Source=="SA_FDis",Source:="f(SA)*f(FD)"];to_gg[Source=="SA_PC1",Source:="f(SA)*f(CWM)"]
to_gg[Source=="SA_CMIave",Source:="f(SA)*CMIave"];to_gg[Source=="SA_MATave",Source:="f(SA)*MATave"]
to_gg[Source=="CMIave_MATave",Source:="CMIave*MATave"];to_gg[Source=="FDis_PC1",Source:="f(FD)*f(CWM)"]
to_gg[Source=="CMIave_FDis",Source:="CMIave*f(FD)"];to_gg[Source=="MATave_FDis",Source:="MATave*f(FD)"]
to_gg[Source=="CMIave_PC1",Source:="CMIave*f(CWM)"];to_gg[Source=="MATave_PC1",Source:="MATave*f(CWM)"]
to_gg$Source<-as.factor(to_gg$Source)
to_gg$Source<-factor(to_gg$Source,levels=c("Int","f(PS)","f(SA)","CMIave","MATave","f(FD)","f(CWM)",
                                           "f(SA)*f(FD)","f(SA)*f(CWM)",
                                           "f(SA)*CMIave","f(SA)*MATave",
                                           "CMIave*MATave","f(FD)*f(CWM)",
                                           "CMIave*f(FD)","MATave*f(FD)",
                                           "CMIave*f(CWM)","MATave*f(CWM)"))

Mort<-ggplot(to_gg[to_gg$Source!="Int"],aes(x=Source,y=mean.Mort,ymin=low.Mort,ymax=up.Mort,col=model))+
  geom_point(position=position_dodge(0.4))+
  geom_errorbar(position=position_dodge(0.4),width=0.3)+
  theme_classic()+
  geom_hline(aes(yintercept=0),linetype="dotted")+
  scale_color_discrete(name="Model")+
  theme(legend.position=c(0.75,0.9),
        axis.text.x=element_text(angle=30,vjust=0.5,size=12),
        axis.text.y=element_text(size=12))+
  ylab("Coefficient estimate")+xlab("")+
  #scale_y_continuous(breaks = c(-0.4,-0.2,0.0,0.2,0.4))+
  guides(col=FALSE)
Mort

################################## NBC ################################## 
glmnet.dat<-can[,.(Intercept=1,PS=sqrtPS,logSA=logSA,CMIave=CMIave,MATave=MATave,FDis=SpFDis,PC1=logPC1,
                   SA_FDis=logSA*SpFDis,SA_PC1=logSA*logPC1,SA_CMIave=logSA*CMIave,SA_MATave=logSA*MATave,
                   CMIave_MATave=CMIave*MATave,FDis_PC1=SpFDis*logPC1,
                   CMIave_FDis=CMIave*SpFDis,MATave_FDis=MATave*SpFDis,
                   CMIave_PC1=CMIave*logPC1,MATave_PC1=MATave*logPC1)]#data table for ridge regression
glmnet.dat<-as.data.table(scale(glmnet.dat))##scale everything
glmnet.dat[,":="(AGB=can$AGB,PLOT_ID=as.factor(can$PLOT_ID),
                 Prov=as.factor(can$Prov),wi=can$wi)]#Add these after scaling

ma_sc<-lmer(AGB~
              PS+logSA+CMIave+MATave+FDis+PC1+
              SA_FDis+SA_PC1+SA_CMIave+SA_MATave+
              CMIave_MATave+FDis_PC1+
              CMIave_FDis+MATave_FDis+
              CMIave_PC1+MATave_PC1+
              (1|PLOT_ID)+(1|Prov),glmnet.dat)
#mixed.bootma_sc<-bootMer(ma_sc,function(.)fixef(.),nsim=1000)
#save(mixed.bootma_sc,file="mixed.bootma_sc.R")
load("mixed.bootma_sc.R")

glmnet.dat[,":="(ran1=ranef(ma_sc)$PLOT_ID[match(glmnet.dat$PLOT_ID,row.names(ranef(ma_sc)$PLOT_ID)),],
                 ran2=ranef(ma_sc)$Prov[match(glmnet.dat$Prov,row.names(ranef(ma_sc)$Prov)),])]

glmnet.dat[,AGB_corr:=AGB-ran1-ran2]##remove the effects of PLOT_ID, Eco, Prov
summary(lm(AGB_corr~PS+logSA+CMIave+MATave+FDis+PC1+
             SA_FDis+SA_PC1+SA_CMIave+SA_MATave+
             CMIave_MATave+FDis_PC1+
             CMIave_FDis+MATave_FDis+
             CMIave_PC1+MATave_PC1,glmnet.dat))$coef
summary(ma_sc)$coef#comparable

lambda_values=summary(sapply(1:100,function(i)cv.glmnet(
  x=as.matrix(glmnet.dat[,.(logSA,PS,CMIave,MATave,FDis,PC1,
                            SA_FDis,SA_PC1,SA_CMIave,SA_MATave,
                            CMIave_MATave,FDis_PC1,
                            CMIave_FDis,MATave_FDis,
                            CMIave_PC1,MATave_PC1)]),
  y=as.matrix(glmnet.dat[,AGB_corr])#,weights=as.vector(glmnet.dat[,wi])
)$lambda.1se))

lambda_values=seq(max(lambda_values),min(lambda_values),length=100)

NBC.gl<-glmnet(AGB_corr~PS,logSA+CMIave+MATave+FDis+PC1+
                 SA_FDis+SA_PC1+SA_CMIave+SA_MATave+
                 CMIave_MATave+FDis_PC1+
                 CMIave_FDis+MATave_FDis+
                 CMIave_PC1+MATave_PC1,
               data=glmnet.dat,
               lambda=lambda_values,#covers range of no suppression to max of 1se
               alpha=0)#0=ridge regression

#bootstrap [lambda=1se]
coeff.se<-ldply(1:1000, function(i){
  too_boot<-sample(unique(glmnet.dat[,PLOT_ID]),replace=TRUE)
  newdat<-glmnet.dat[PLOT_ID%in%too_boot]
  newdat[,":="(Prov=glmnet.dat[match(newdat$PLOT_ID,PLOT_ID),Prov])]
  
  lmerboot<-(lmer(AGB~PS+logSA+CMIave+MATave+FDis+PC1+
                    SA_FDis+SA_PC1+SA_CMIave+SA_MATave+
                    CMIave_MATave+FDis_PC1+
                    CMIave_FDis+MATave_FDis+
                    CMIave_PC1+MATave_PC1+
                    (1|PLOT_ID)+(1|Prov),
                  data=newdat))
  
  newdat[,":="(ran1=ranef(lmerboot)$PLOT_ID[match(newdat$PLOT_ID,row.names(ranef(lmerboot)$PLOT_ID)),],
               ran2=ranef(lmerboot)$Prov[match(newdat$Prov,row.names(ranef(lmerboot)$Prov)),])]
  
  newdat[,AGB_corr:=AGB-ran1-ran2]
  
  NBC.gl2<-glmnet(AGB_corr~PS+logSA+CMIave+MATave+FDis+PC1+
                    SA_FDis+SA_PC1+SA_CMIave+SA_MATave+
                    CMIave_MATave+FDis_PC1+
                    CMIave_FDis+MATave_FDis+
                    CMIave_PC1+MATave_PC1,
                  data=newdat,
                  lambda=lambda_values,
                  alpha=0)
  coef(NBC.gl2)@x},.progress="win"
)%>%as.data.table

#fwrite(coeff.se,"Ridge_regression_coeff.1se.NBC.csv")
coeff.se<-fread("Ridge_regression_coeff.1se.NBC.csv")

colnames(coeff.se)<-rep(c("Int","PS","logSA","CMIave","MATave","FDis","PC1",
                          "SA_FDis","SA_PC1","SA_CMIave","SA_MATave",
                          "CMIave_MATave","FDis_PC1",
                          "CMIave_FDis","MATave_FDis",
                          "CMIave_PC1","MATave_PC1"),
                        ncol(coeff.se)/17)

coeff.se_tidy<-data.table(Int=unlist(apply(coeff.se[,grep("Int",colnames(coeff.se)),with=FALSE],2,list)),
                          PS=unlist(apply(coeff.se[,grep("PS",colnames(coeff.se)),with=FALSE],2,list)),
                          logSA=unlist(apply(coeff.se[,grep("logSA",colnames(coeff.se)),with=FALSE],2,list)),
                          CMIave=unlist(apply(coeff.se[,grep("^CMIave$",colnames(coeff.se)),with=FALSE],2,list)),
                          MATave=unlist(apply(coeff.se[,grep("^MATave$",colnames(coeff.se)),with=FALSE],2,list)),
                          FDis=unlist(apply(coeff.se[,grep("^FDis$",colnames(coeff.se)),with=FALSE],2,list)),
                          PC1=unlist(apply(coeff.se[,grep("^PC1$",colnames(coeff.se)),with=FALSE],2,list)),
                          SA_FDis=unlist(apply(coeff.se[,grep("^SA_FDis$",colnames(coeff.se)),with=FALSE],2,list)),
                          SA_PC1=unlist(apply(coeff.se[,grep("^SA_PC1$",colnames(coeff.se)),with=FALSE],2,list)),
                          SA_CMIave=unlist(apply(coeff.se[,grep("^SA_CMIave$",colnames(coeff.se)),with=FALSE],2,list)),
                          SA_MATave=unlist(apply(coeff.se[,grep("^SA_MATave$",colnames(coeff.se)),with=FALSE],2,list)),
                          CMIave_MATave=unlist(apply(coeff.se[,grep("^CMIave_MATave$",colnames(coeff.se)),with=FALSE],2,list)),
                          FDis_PC1=unlist(apply(coeff.se[,grep("^FDis_PC1$",colnames(coeff.se)),with=FALSE],2,list)),
                          CMIave_FDis=unlist(apply(coeff.se[,grep("^CMIave_FDis$",colnames(coeff.se)),with=FALSE],2,list)),
                          MATave_FDis=unlist(apply(coeff.se[,grep("^MATave_FDis$",colnames(coeff.se)),with=FALSE],2,list)),
                          CMIave_PC1=unlist(apply(coeff.se[,grep("^CMIave_PC1$",colnames(coeff.se)),with=FALSE],2,list)),
                          MATave_PC1=unlist(apply(coeff.se[,grep("^MATave_PC1$",colnames(coeff.se)),with=FALSE],2,list)))

NBCT_1se<-data.table(Source=c("Int","PS","logSA","CMIave","MATave","FDis","PC1",
                              "SA_FDis","SA_PC1","SA_CMIave","SA_MATave",
                              "CMIave_MATave","FDis_PC1",
                              "CMIave_FDis","MATave_FDis",
                              "CMIave_PC1","MATave_PC1"),
                     mean.NBC=NA,up.NBC=NA,low.NBC=NA)

NBCT_1se$mean.NBC<-apply(coeff.se_tidy,2,mean)
NBCT_1se$up.NBC<-apply(coeff.se_tidy,2,function(x){quantile(x,0.975)})
NBCT_1se$low.NBC<-apply(coeff.se_tidy,2,function(x){quantile(x,0.025)})

## Multi Linear mixed effects (bootstrap) ##
NBCT_multi<-data.table(Source=c("Int","PS","logSA","CMIave","MATave","FDis","PC1",
                                "SA_FDis","SA_PC1","SA_CMIave","SA_MATave",
                                "CMIave_MATave","FDis_PC1",
                                "CMIave_FDis","MATave_FDis",
                                "CMIave_PC1","MATave_PC1"),
                       mean.NBC=NA,up.NBC=NA,low.NBC=NA)

NBCT_multi$mean.NBC<-fixef(ma_sc)
NBCT_multi$up.NBC<-apply(mixed.bootma_sc$t,2,function(x){quantile(x,0.975)})
NBCT_multi$low.NBC<-apply(mixed.bootma_sc$t,2,function(x){quantile(x,0.025)})

#nonpara
nma_sc<-rfit(AGB_corr~PS+logSA+CMIave+MATave+FDis+PC1+
               SA_FDis+SA_PC1+SA_CMIave+SA_MATave+
               CMIave_MATave+FDis_PC1+
               CMIave_FDis+MATave_FDis+
               CMIave_PC1+MATave_PC1,
             data=glmnet.dat)
summary(nma_sc)$co

NBCT_multi_NP<-data.table(Source=c("Int","PS","logSA","CMIave","MATave","FDis","PC1",
                                   "SA_FDis","SA_PC1","SA_CMIave","SA_MATave",
                                   "CMIave_MATave","FDis_PC1",
                                   "CMIave_FDis","MATave_FDis",
                                   "CMIave_PC1","MATave_PC1"),
                          mean.NBC=NA,up.NBC=NA,low.NBC=NA)

NBCT_multi_NP$mean.NBC<-summary(nma_sc)$co[,1]
NBCT_multi_NP$up.NBC<-summary(nma_sc)$co[,1]+summary(nma_sc)$co[,2]
NBCT_multi_NP$low.NBC<-summary(nma_sc)$co[,1]-summary(nma_sc)$co[,2]

## CMIave Linear mixed effects (bootstrap) ##
NBCT_CMIave<-data.table(Source=c("Int","PS","logSA","CMIave","FDis","PC1",
                                 "SA_FDis","SA_PC1","SA_CMIave",
                                 "FDis_PC1",
                                 "CMIave_FDis",
                                 "CMIave_PC1"),
                        mean.NBC=NA,up.NBC=NA,low.NBC=NA)

maCMIave_sc<-lmer(AGB~PS+logSA+CMIave+FDis+PC1+
                    SA_FDis+SA_PC1+SA_CMIave+
                    FDis_PC1+CMIave_FDis+CMIave_PC1+
                    (1|PLOT_ID)+(1|Prov),glmnet.dat)
#mixed.bootma_CMIave_sc<-bootMer(maCMIave_sc,function(.)fixef(.),nsim=1000)
#save(mixed.bootma_CMIave_sc,file="mixed.bootma_CMIave_sc.R")
load("mixed.bootma_CMIave_sc.R")

NBCT_CMIave$mean.NBC<-fixef(maCMIave_sc)
NBCT_CMIave$up.NBC<-apply(mixed.bootma_CMIave_sc$t,2,function(x){quantile(x,0.975)})
NBCT_CMIave$low.NBC<-apply(mixed.bootma_CMIave_sc$t,2,function(x){quantile(x,0.025)})

## MATave Linear mixed effects (bootstrap) ##
NBCT_MATave<-data.table(Source=c("Int","PS","logSA","MATave","FDis","PC1",
                                 "SA_FDis","SA_PC1","SA_MATave",
                                 "FDis_PC1",
                                 "MATave_FDis",
                                 "MATave_PC1"),
                        mean.NBC=NA,up.NBC=NA,low.NBC=NA)

maMATave_sc<-lmer(AGB~PS+logSA+MATave+FDis+PC1+
                    SA_FDis+SA_PC1+SA_MATave+
                    FDis_PC1+MATave_FDis+MATave_PC1+
                    (1|PLOT_ID)+(1|Prov),glmnet.dat)
#mixed.bootma_MATave_sc<-bootMer(maMATave_sc,function(.)fixef(.),nsim=1000)
#save(mixed.bootma_MATave_sc,file="mixed.bootma_MATave_sc.R")
load("mixed.bootma_MATave_sc.R")

NBCT_MATave$mean.NBC<-fixef(maMATave_sc)
NBCT_MATave$up.NBC<-apply(mixed.bootma_MATave_sc$t,2,function(x){quantile(x,0.975)})
NBCT_MATave$low.NBC<-apply(mixed.bootma_MATave_sc$t,2,function(x){quantile(x,0.025)})

#Bind
NBCT_multi$model<-"Linear mixed effects (modelled with CMIave and MAT simultaneously)"
NBCT_1se$model<-"Ridge regression (modelled with CMIave and MAT simultaneously)"
NBCT_multi_NP$model<-"Nonparametric (modelled with CMIave and MAT simultaneously)"
NBCT_CMIave$model<-"Linear mixed effects (modelled with CMIave)"
NBCT_MATave$model<-"Linear mixed effects (modelled with MATave)"

to_gg<-rbind(NBCT_multi,NBCT_1se,NBCT_multi_NP,NBCT_CMIave,NBCT_MATave)
to_gg$model<-factor(to_gg$model,levels=c("Linear mixed effects (modelled with CMIave and MAT simultaneously)",
                                         "Ridge regression (modelled with CMIave and MAT simultaneously)",
                                         "Nonparametric (modelled with CMIave and MAT simultaneously)",
                                         "Linear mixed effects (modelled with CMIave)",
                                         "Linear mixed effects (modelled with MATave)"))
to_gg[Source=="PS",Source:="f(PS)"];to_gg[Source=="logSA",Source:="f(SA)"]
to_gg[Source=="FDis",Source:="FD"];to_gg[Source=="PC1",Source:="f(CWM)"]
to_gg[Source=="SA_FDis",Source:="f(SA)*FD"];to_gg[Source=="SA_PC1",Source:="f(SA)*f(CWM)"]
to_gg[Source=="SA_CMIave",Source:="f(SA)*CMIave"];to_gg[Source=="SA_MATave",Source:="f(SA)*MATave"]
to_gg[Source=="CMIave_MATave",Source:="CMIave*MATave"];to_gg[Source=="FDis_PC1",Source:="FD*f(CWM)"]
to_gg[Source=="CMIave_FDis",Source:="CMIave*FD"];to_gg[Source=="MATave_FDis",Source:="MATave*FD"]
to_gg[Source=="CMIave_PC1",Source:="CMIave*f(CWM)"];to_gg[Source=="MATave_PC1",Source:="MATave*f(CWM)"]
to_gg$Source<-as.factor(to_gg$Source)
to_gg$Source<-factor(to_gg$Source,levels=c("Int","f(PS)","f(SA)","CMIave","MATave","FD","f(CWM)",
                                           "f(SA)*FD","f(SA)*f(CWM)",
                                           "f(SA)*CMIave","f(SA)*MATave",
                                           "CMIave*MATave","FD*f(CWM)",
                                           "CMIave*FD","MATave*FD",
                                           "CMIave*f(CWM)","MATave*f(CWM)"))

NBC<-ggplot(to_gg[to_gg$Source!="Int"],aes(x=Source,y=mean.NBC,ymin=low.NBC,ymax=up.NBC,col=model))+
  geom_point(position=position_dodge(0.4))+
  geom_errorbar(position=position_dodge(0.4),width=0.3)+
  theme_classic()+
  geom_hline(aes(yintercept=0),linetype="dotted")+
  scale_color_discrete(name="Model")+
  theme(legend.position=c(0.75,0.9),
        axis.text.x=element_text(angle=30,vjust=0.5,size=12),
        axis.text.y=element_text(size=12))+
  ylab("Coefficient estimate")+xlab("")+
  #scale_y_continuous(breaks = c(-0.8,-0.6,-0.4,-0.2,0.0,0.2,0.4,0.6))+
  guides(col=FALSE)
NBC

############## Bind Gr, M, NBC ##############
rbind_gtable_max <- function(...){
  gtl <- list(...)
  stopifnot(all(sapply(gtl, is.gtable)))
  bind2 <- function (x, y) 
  {
    stopifnot(ncol(x) == ncol(y))
    if (nrow(x) == 0) 
      return(y)
    if (nrow(y) == 0) 
      return(x)
    y$layout$t <- y$layout$t + nrow(x)
    y$layout$b <- y$layout$b + nrow(x)
    x$layout <- rbind(x$layout, y$layout)
    x$heights <- gtable:::insert.unit(x$heights, y$heights)
    x$rownames <- c(x$rownames, y$rownames)
    x$widths <- grid::unit.pmax(x$widths, y$widths)
    x$grobs <- append(x$grobs, y$grobs)
    x
  }
  
  Reduce(bind2, gtl)
}

p1<-ggplot_gtable(ggplot_build(Grow))
p2<-ggplot_gtable(ggplot_build(Mort))
p3<-ggplot_gtable(ggplot_build(NBC))

maxWidth = unit.pmax(p1$widths[2:3], p2$widths[2:3], p3$widths[2:3])

p1$widths[2:3] <- maxWidth
p2$widths[2:3] <- maxWidth
p3$widths[2:3] <- maxWidth

maxheight = unit.pmax(p1$heights[2:3], p2$heights[2:3], p3$heights[2:3])

p1$heights[2:3] <- maxheight
p2$heights[2:3] <- maxheight
p3$heights[2:3] <- maxheight

tiff("FigS5_NEW_Bind_MULTI_Ridge_NonPara_EACH_20191031.tiff",width=3800,height=4000,res=300,compression="lzw")
grid.draw(rbind(p1,p2,p3,size="last"))
grid.text("(a) Growth",x=unit(0.1,"npc"),y=unit(0.99,"npc"),gp=gpar(fontsize=14),just="left")
grid.text("(b) Mortality",x=unit(0.1,"npc"),y=unit(0.67,"npc"),gp=gpar(fontsize=14),just="left")
grid.text("(c) Net biomass change",x=unit(0.1,"npc"),y=unit(0.33,"npc"),gp=gpar(fontsize=14),just="left")

dev.off()
