#rm(list=ls())
library(lme4);library(lmerTest)
library(nlme)
library(boot);library(Rfit)
library(MuMIn);library(ggplot2)
library(grid);library(gridExtra)
library(gtable);library(plyr)
library(dplyr);library(data.table)
library(MuMIn);options(na.action = "na.fail")
library(glmnet);library(glmnetUtils)
library(SoDA);library(spdep);library(spaMM)

## Growth
#FD effects depends on SA
coefmean<-summary(mb)$co[,1]
coefSE<-summary(mb)$co[,2]
plot_df<-expand.grid(sqrtFDis=can$sqrtFDis,logSA=round(c(seq(quantile(can$logSA,0.05)[[1]],
                                                             quantile(can$logSA,0.95)[[1]],length=3),0),2)) %>%
  mutate(mean=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["sqrtFDis"]*sqrtFDis+
           coefmean["logSA:sqrtFDis"]*logSA*sqrtFDis) %>% 
  mutate(up=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["sqrtFDis"]*sqrtFDis+
           coefmean["logSA:sqrtFDis"]*logSA*sqrtFDis+
           coefSE["(Intercept)"]+coefSE["logSA"]*logSA+coefSE["sqrtFDis"]*sqrtFDis+
           coefSE["logSA:sqrtFDis"]*logSA*sqrtFDis) %>% 
  mutate(low=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["sqrtFDis"]*sqrtFDis+
           coefmean["logSA:sqrtFDis"]*logSA*sqrtFDis-
           (coefSE["(Intercept)"]+coefSE["logSA"]*logSA+coefSE["sqrtFDis"]*sqrtFDis+
              coefSE["logSA:sqrtFDis"]*logSA*sqrtFDis)) %>% 
  as.data.table()
plot_df[,":="(sqrtFDis1=sqrtFDis*sd(can$sqrtFDis1)+mean(can$sqrtFDis1),logSA1=logSA*sd(can$logSA1)+mean(can$logSA1))] %>% 
  .[,":="(logSA=as.factor(round(logSA,2)),logSA1=as.factor(round(logSA1,2)))]
head(plot_df);nrow(plot_df)

FD_Grow_SA<-ggplot(plot_df,aes(y=mean,x=(sqrtFDis1)^2,color=logSA))+
  theme_classic()+
  geom_ribbon(aes(x=(sqrtFDis1)^2,ymin=low,ymax=up,
                  group=logSA),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1.1)+
  scale_colour_manual(values=c("maroon2","black","lightslateblue","dodgerblue4"),name="",
                      labels=c("-0.83841231"="1.00","-0.4126802475"="2.12","0.013051815"="3.25",
                               "0.4387838775"="4.37","0.86451594"="5.31","0"="Mean"),
                      guide=guide_legend(override.aes = list(colour=NA,fill=NA)))+
  xlab("")+
  ylab(expression(paste("Growth (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x= element_blank(), axis.line.y = element_line(),
        legend.title.align = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))
FD_Grow_SA<-FD_Grow_SA+annotate("text",x=0.15,y=4.5,label="sqrt(FD)%*%ln(SA):~italic(P) <0.001",parse=TRUE,size=3.5)
FD_Grow_SA

summary(mb)$co

#SA effect depends on logPC1
coefmean<-summary(mb)$co[,1]
coefSE<-summary(mb)$co[,2]
plot_df<-expand.grid(logPC1=can$logPC1,logSA=round(c(seq(quantile(can$logSA,0.05)[[1]],
                                                         quantile(can$logSA,0.95)[[1]],length=3),0),2)) %>%
  mutate(mean=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["logPC1"]*logPC1+
           coefmean["logSA:logPC1"]*logSA*logPC1) %>% 
  mutate(up=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["logPC1"]*logPC1+
           coefmean["logSA:logPC1"]*logSA*logPC1+
           coefSE["(Intercept)"]+coefSE["logSA"]*logSA+coefSE["logPC1"]*logPC1+
           coefSE["logSA:logPC1"]*logSA*logPC1) %>% 
  mutate(low=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["logPC1"]*logPC1+
           coefmean["logSA:logPC1"]*logSA*logPC1-
           (coefSE["(Intercept)"]+coefSE["logSA"]*logSA+coefSE["logPC1"]*logPC1+
              coefSE["logSA:logPC1"]*logSA*logPC1)) %>% 
  as.data.table()
plot_df[,":="(logPC11=logPC1*sd(can$logPC11)+mean(can$logPC11),logSA1=logSA*sd(can$logSA1)+mean(can$logSA1))] %>% 
  .[,":="(logSA=as.factor(round(logSA,2)),logSA1=as.factor(round(logSA1,2)))]
head(plot_df);nrow(plot_df)

PC1_Grow_SA<-ggplot(plot_df,aes(y=mean,x=exp(logPC11),color=logSA))+
  theme_classic()+
  geom_ribbon(aes(x=exp(logPC11),ymin=low,ymax=up,
                  group=logSA),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1.1)+
  scale_colour_manual(values=c("violetred3","black","violet","turquoise"),name="",
                      labels=c("-0.83841231"="1.00", "-0.4126802475"="2.12","0.013051815"="3.25",
                               "0.4387838775"="4.37","0.86451594"="5.31","0"="Mean"),
                      guide=guide_legend(override.aes = list(colour=NA,fill=NA)))+
  xlab("")+
  ylab(expression(paste("Growth (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x= element_blank(), axis.line.y = element_line(),
        legend.title.align = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))
PC1_Grow_SA<-PC1_Grow_SA+annotate("text",x=4.5,y=3.8,label="ln(CWMPC1)%*%ln(SA):~italic(P) == 0.048",parse=TRUE,size=3.5)
PC1_Grow_SA

summary(mb)$co

## Mortality
#SA effects depends on sqrtFDis
coefmean<-summary(mc)$co[,1]
coefSE<-summary(mc)$co[,2]
plot_df<-expand.grid(sqrtFDis=can$sqrtFDis,logSA=round(c(seq(quantile(can$logSA,0.05)[[1]],
                                                             quantile(can$logSA,0.95)[[1]],length=3),0),2)) %>%
  mutate(mean=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["sqrtFDis"]*sqrtFDis+
           coefmean["logSA:sqrtFDis"]*logSA*sqrtFDis) %>% 
  mutate(up=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["sqrtFDis"]*sqrtFDis+
           coefmean["logSA:sqrtFDis"]*logSA*sqrtFDis+
           coefSE["(Intercept)"]+coefSE["logSA"]*logSA+coefSE["sqrtFDis"]*sqrtFDis+
           coefSE["logSA:sqrtFDis"]*logSA*sqrtFDis) %>% 
  mutate(low=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["sqrtFDis"]*sqrtFDis+
           coefmean["logSA:sqrtFDis"]*logSA*sqrtFDis-
           (coefSE["(Intercept)"]+coefSE["logSA"]*logSA+coefSE["sqrtFDis"]*sqrtFDis+
              coefSE["logSA:sqrtFDis"]*logSA*sqrtFDis)) %>% 
  as.data.table()
plot_df[,":="(sqrtFDis1=sqrtFDis*sd(can$sqrtFDis1)+mean(can$sqrtFDis1),logSA1=logSA*sd(can$logSA1)+mean(can$logSA1))] %>% 
  .[,":="(logSA=as.factor(round(logSA,2)),logSA1=as.factor(round(logSA1,2)))]
head(plot_df);nrow(plot_df)

seq(quantile(can$SA1,0.05)[[1]],quantile(can$SA1,0.95)[[1]],length=3);mean(can$SA1)
FD_Mort_SA<-ggplot(plot_df,aes(y=mean,x=(sqrtFDis1)^2,color=logSA))+
  theme_classic()+
  geom_ribbon(aes(x=(sqrtFDis1)^2,ymin=low,ymax=up,
                  group=logSA),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1.1)+
  scale_colour_manual(values=c("maroon2","black","lightslateblue","dodgerblue4"),name="Stand age (yrs)",
                      labels=c("-1.75"="31.0", "-0.14"="97.4","1.46"="163.9","0"="Mean (86.3)"))+
  xlab("")+
  ylab(expression(paste("Mortality (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x= element_blank(), axis.line.y = element_line(),
        legend.title.align  = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour="black"))#+
  #ylim(0,4.5)
FD_Mort_SA<-FD_Mort_SA+annotate("text",x=0.15,y=3,label="sqrt(FD)%*%ln(SA):~italic(P) <0.001",parse=TRUE,size=3.5)
FD_Mort_SA

summary(mc)$co

#SA effect depends on sqrtPC1
coefmean<-summary(mc)$co[,1]
coefSE<-summary(mc)$co[,2]
plot_df<-expand.grid(sqrtPC1=can$sqrtPC1,logSA=round(c(seq(quantile(can$logSA,0.05)[[1]],
                                                           quantile(can$logSA,0.95)[[1]],length=3),0),2)) %>%
  mutate(mean=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["sqrtPC1"]*sqrtPC1+
           coefmean["logSA:sqrtPC1"]*logSA*sqrtPC1) %>% 
  mutate(up=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["sqrtPC1"]*sqrtPC1+
           coefmean["logSA:sqrtPC1"]*logSA*sqrtPC1+
           coefSE["(Intercept)"]+coefSE["logSA"]*logSA+coefSE["sqrtPC1"]*sqrtPC1+
           coefSE["logSA:sqrtPC1"]*logSA*sqrtPC1) %>% 
  mutate(low=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["sqrtPC1"]*sqrtPC1+
           coefmean["logSA:sqrtPC1"]*logSA*sqrtPC1-
           (coefSE["(Intercept)"]+coefSE["logSA"]*logSA+coefSE["sqrtPC1"]*sqrtPC1+
              coefSE["logSA:sqrtPC1"]*logSA*sqrtPC1)) %>% 
  as.data.table()
plot_df[,":="(sqrtPC11=sqrtPC1*sd(can$sqrtPC11)+mean(can$sqrtPC11),logSA1=logSA*sd(can$logSA1)+mean(can$logSA1))] %>% 
  .[,":="(logSA=as.factor(round(logSA,2)),logSA1=as.factor(round(logSA1,2)))]
head(plot_df);nrow(plot_df)

PC1_Mort_SA<-ggplot(plot_df,aes(y=mean,x=(sqrtPC11)^2,color=logSA))+
  theme_classic()+
  geom_ribbon(aes(x=(sqrtPC11)^2,ymin=low,ymax=up,
                  group=logSA),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1.1)+
  scale_colour_manual(values=c("violetred3","black","violet","turquoise"),name="Stand age (yrs)",
                      labels=c("-1.75"="31.0", "-0.14"="97.4","1.46"="163.9","0"="Mean (86.3)"))+
  xlab("")+
  ylab(expression(paste("Mortality (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x= element_blank(), axis.line.y = element_line(),
        legend.title.align  = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour="black"))#+
#ylim(-0.05,5)
PC1_Mort_SA<-PC1_Mort_SA+annotate("text",x= 4,y=3.5,label="sqrt(CWMPC1)%*%ln(SA):~italic(P) == 0.127",parse=TRUE,size=3.5)
PC1_Mort_SA

summary(mc)$co

## Net biomass change
#SA effects depends on SpFDis
coefmean<-summary(ma)$co[,1]
coefSE<-summary(ma)$co[,2]
plot_df<-expand.grid(SpFDis=can$SpFDis,logSA=round(c(seq(quantile(can$logSA,0.05)[[1]],
                                                         quantile(can$logSA,0.95)[[1]],length=3),0),2)) %>%
  mutate(mean=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["SpFDis"]*SpFDis+
           coefmean["logSA:SpFDis"]*logSA*SpFDis) %>% 
  mutate(up=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["SpFDis"]*SpFDis+
           coefmean["logSA:SpFDis"]*logSA*SpFDis+
           coefSE["(Intercept)"]+coefSE["logSA"]*logSA+coefSE["SpFDis"]*SpFDis+
           coefSE["logSA:SpFDis"]*logSA*SpFDis) %>% 
  mutate(low=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["SpFDis"]*SpFDis+
           coefmean["logSA:SpFDis"]*logSA*SpFDis-
           (coefSE["(Intercept)"]+coefSE["logSA"]*logSA+coefSE["SpFDis"]*SpFDis+
              coefSE["logSA:SpFDis"]*logSA*SpFDis)) %>% 
  as.data.table()
plot_df[,":="(SpFDis1=SpFDis*sd(can$SpFDis1)+mean(can$SpFDis1),logSA1=logSA*sd(can$logSA1)+mean(can$logSA1))] %>% 
  .[,":="(logSA=as.factor(round(logSA,2)),logSA1=as.factor(round(logSA1,2)))]
head(plot_df);nrow(plot_df)

FD_NBC_SA<-ggplot(plot_df,aes(y=mean,x=(SpFDis1),color=logSA))+
  theme_classic()+
  geom_ribbon(aes(x=(SpFDis1),ymin=low,ymax=up,
                  group=logSA),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1.1)+
  scale_colour_manual(values=c("maroon2","black","lightslateblue","dodgerblue4"),name="",
                      labels=c("-0.83841231"="1.00","-0.4126802475"="2.12","0.013051815"="3.25",
                               "0.4387838775"="4.37","0.86451594"="5.31","0"="Mean"),
                      guide=guide_legend(override.aes = list(colour=NA,fill=NA)))+
  xlab(expression(paste(FD[ave]," (cm)")))+
  ylab(expression(paste("Net biomass change (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.line.y = element_line(),
        legend.title.align = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))
FD_NBC_SA<-FD_NBC_SA+annotate("text",x=0.15,y=3,label="FD%*%ln(SA):~italic(P) <0.001",parse=TRUE,size=3.5)
FD_NBC_SA

summary(ma)$co

#SA effect depends on logPC1
coefmean<-summary(ma)$co[,1]
coefSE<-summary(ma)$co[,2]
plot_df<-expand.grid(logPC1=can$logPC1,logSA=round(c(seq(quantile(can$logSA,0.05)[[1]],
                                                         quantile(can$logSA,0.95)[[1]],length=3),0),2)) %>%
  mutate(mean=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["logPC1"]*logPC1+
           coefmean["logSA:logPC1"]*logSA*logPC1) %>% 
  mutate(up=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["logPC1"]*logPC1+
           coefmean["logSA:logPC1"]*logSA*logPC1+
           coefSE["(Intercept)"]+coefSE["logSA"]*logSA+coefSE["logPC1"]*logPC1+
           coefSE["logSA:logPC1"]*logSA*logPC1) %>% 
  mutate(low=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["logPC1"]*logPC1+
           coefmean["logSA:logPC1"]*logSA*logPC1-
           (coefSE["(Intercept)"]+coefSE["logSA"]*logSA+coefSE["logPC1"]*logPC1+
              coefSE["logSA:logPC1"]*logSA*logPC1)) %>% 
  as.data.table()
plot_df[,":="(logPC11=logPC1*sd(can$logPC11)+mean(can$logPC11),logSA1=logSA*sd(can$logSA1)+mean(can$logSA1))] %>% 
  .[,":="(logSA=as.factor(round(logSA,2)),logSA1=as.factor(round(logSA1,2)))]
head(plot_df);nrow(plot_df)

PC1_NBC_SA<-ggplot(plot_df,aes(y=mean,x=exp(logPC11),color=logSA))+
  theme_classic()+
  geom_ribbon(aes(x=exp(logPC11),ymin=low,ymax=up,
                  group=logSA),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1.1)+
  scale_colour_manual(values=c("violetred3","black","violet","turquoise"),name="",
                      labels=c("-0.83841231"="1.00", "-0.4126802475"="2.12","0.013051815"="3.25",
                               "0.4387838775"="4.37","0.86451594"="5.31","0"="Mean"),
                      guide=guide_legend(override.aes = list(colour=NA,fill=NA)))+
  xlab(expression(paste(logPC1[ave]," (",~degree*C,")")))+
  ylab(expression(paste("Net biomass change (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.line.y = element_line(),
        legend.title.align = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))
PC1_NBC_SA<-PC1_NBC_SA+annotate("text",x=4,y=3,label="ln(CWMPC1)%*%ln(SA):~italic(P) == 0.188",parse=TRUE,size=3.5)
PC1_NBC_SA

summary(ma)$co

#bind
i1 <- ggplotGrob(FD_Grow_SA)
i2 <- ggplotGrob(FD_Mort_SA)
i3 <- ggplotGrob(FD_NBC_SA)

j1 <- ggplotGrob(PC1_Grow_SA)
j2 <- ggplotGrob(PC1_Mort_SA)
j3 <- ggplotGrob(PC1_NBC_SA)

maxWidth = unit.pmax(i1$widths[2:3], i2$widths[2:3], i3$widths[2:3])
i1$widths[2:3] <- maxWidth
i2$widths[2:3] <- maxWidth
i3$widths[2:3] <- maxWidth

maxWidth = unit.pmax(j1$widths[2:3], j2$widths[2:3], j3$widths[2:3])
j1$widths[2:3] <- maxWidth
j2$widths[2:3] <- maxWidth
j3$widths[2:3] <- maxWidth

tiff("FigS_FD_PC1_effects_by_SA.tiff",width=2500,height=3000,res=300,compression="lzw")
grid.draw(cbind(rbind(i1,i2,i3,size="last"),rbind(j1,j2,j3,size="last"),size="first"))
grid.text("(a)",x=unit(0.02,"npc"),y=unit(0.993,"npc"),gp=gpar(fontsize=14,font=2))
grid.text("(b)",x=unit(0.52,"npc"),y=unit(0.993,"npc"),gp=gpar(fontsize=14,font=2))

dev.off()

## Growth
#SA effects depends on CMIave
coefmean<-summary(mb)$co[,1]
coefSE<-summary(mb)$co[,2]
plot_df<-expand.grid(CMIave=can$CMIave,logSA=round(c(seq(quantile(can$logSA,0.05)[[1]],quantile(can$logSA,0.95)[[1]],length=3),0),2)) %>%
  mutate(mean=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["CMIave"]*CMIave+
           coefmean["logSA:CMIave"]*logSA*CMIave) %>% 
  mutate(up=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["CMIave"]*CMIave+
           coefmean["logSA:CMIave"]*logSA*CMIave+
           coefSE["(Intercept)"]+coefSE["logSA"]*logSA+coefSE["CMIave"]*CMIave+
           coefSE["logSA:CMIave"]*logSA*CMIave) %>% 
  mutate(low=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["CMIave"]*CMIave+
           coefmean["logSA:CMIave"]*logSA*CMIave-
           (coefSE["(Intercept)"]+coefSE["logSA"]*logSA+coefSE["CMIave"]*CMIave+
              coefSE["logSA:CMIave"]*logSA*CMIave)) %>% 
  as.data.table()
plot_df[,":="(CMIave1=CMIave*sd(can$CMIave1)+mean(can$CMIave1),logSA1=logSA*sd(can$logSA1)+mean(can$logSA1))] %>% 
  .[,":="(logSA=as.factor(round(logSA,2)),logSA1=as.factor(round(logSA1,2)))]
head(plot_df);nrow(plot_df)

CMI_Grow_SA<-ggplot(plot_df,aes(y=mean,x=(CMIave1),color=logSA))+
  theme_classic()+
  geom_ribbon(aes(x=(CMIave1),ymin=low,ymax=up,
                  group=logSA),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1.1)+
  scale_colour_manual(values=c("maroon2","black","lightslateblue","dodgerblue4"),name="",
                      labels=c("-0.83841231"="1.00","-0.4126802475"="2.12","0.013051815"="3.25",
                               "0.4387838775"="4.37","0.86451594"="5.31","0"="Mean"),
                      guide=guide_legend(override.aes = list(colour=NA,fill=NA)))+
  xlab("")+
  ylab(expression(paste("Growth (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x= element_blank(), axis.line.y = element_line(),
        legend.title.align = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))
CMI_Grow_SA<-CMI_Grow_SA+annotate("text",x=150,y=11,label="ln(SA):~italic(P) <0.001",parse=TRUE,size=3.5)
CMI_Grow_SA<-CMI_Grow_SA+annotate("text",x=150,y=10,label="CMIave%*%ln(SA):~italic(P) == 0.003",parse=TRUE,size=3.5)
CMI_Grow_SA

summary(mb)$co

#SA effect depends on MATave
coefmean<-summary(mb)$co[,1]
coefSE<-summary(mb)$co[,2]
plot_df<-expand.grid(MATave=can$MATave,logSA=round(c(seq(quantile(can$logSA,0.05)[[1]],quantile(can$logSA,0.95)[[1]],length=3),0),2)) %>%
  mutate(mean=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["MATave"]*MATave+
           coefmean["logSA:MATave"]*logSA*MATave) %>% 
  mutate(up=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["MATave"]*MATave+
           coefmean["logSA:MATave"]*logSA*MATave+
           coefSE["(Intercept)"]+coefSE["logSA"]*logSA+coefSE["MATave"]*MATave+
           coefSE["logSA:MATave"]*logSA*MATave) %>% 
  mutate(low=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["MATave"]*MATave+
           coefmean["logSA:MATave"]*logSA*MATave-
           (coefSE["(Intercept)"]+coefSE["logSA"]*logSA+coefSE["MATave"]*MATave+
              coefSE["logSA:MATave"]*logSA*MATave)) %>% 
  as.data.table()
plot_df[,":="(MATave1=MATave*sd(can$MATave1)+mean(can$MATave1),logSA1=logSA*sd(can$logSA1)+mean(can$logSA1))] %>% 
  .[,":="(logSA=as.factor(round(logSA,2)),logSA1=as.factor(round(logSA1,2)))]
head(plot_df);nrow(plot_df)

MAT_Grow_SA<-ggplot(plot_df,aes(y=mean,x=(MATave1),color=logSA))+
  theme_classic()+
  geom_ribbon(aes(x=(MATave1),ymin=low,ymax=up,
                  group=logSA),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1.1)+
  scale_colour_manual(values=c("violetred3","black","violet","turquoise"),name="",
                      labels=c("-0.83841231"="1.00", "-0.4126802475"="2.12","0.013051815"="3.25",
                               "0.4387838775"="4.37","0.86451594"="5.31","0"="Mean"),
                      guide=guide_legend(override.aes = list(colour=NA,fill=NA)))+
  xlab("")+
  ylab(expression(paste("Growth (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x= element_blank(), axis.line.y = element_line(),
        legend.title.align = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))
MAT_Grow_SA<-MAT_Grow_SA+annotate("text",x=3,y=6.5,label="MATave%*%ln(SA):~italic(P) == 0.203",parse=TRUE,size=3.5)
MAT_Grow_SA

summary(mb)$co

## Mortality
#SA effects depends on CMIave
coefmean<-summary(mc)$co[,1]
coefSE<-summary(mc)$co[,2]
plot_df<-expand.grid(CMIave=can$CMIave,logSA=round(c(seq(quantile(can$logSA,0.05)[[1]],quantile(can$logSA,0.95)[[1]],length=3),0),2)) %>%
  mutate(mean=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["CMIave"]*CMIave+
           coefmean["logSA:CMIave"]*logSA*CMIave) %>% 
  mutate(up=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["CMIave"]*CMIave+
           coefmean["logSA:CMIave"]*logSA*CMIave+
           coefSE["(Intercept)"]+coefSE["logSA"]*logSA+coefSE["CMIave"]*CMIave+
           coefSE["logSA:CMIave"]*logSA*CMIave) %>% 
  mutate(low=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["CMIave"]*CMIave+
           coefmean["logSA:CMIave"]*logSA*CMIave-
           (coefSE["(Intercept)"]+coefSE["logSA"]*logSA+coefSE["CMIave"]*CMIave+
              coefSE["logSA:CMIave"]*logSA*CMIave)) %>% 
  as.data.table()
plot_df[,":="(CMIave1=CMIave*sd(can$CMIave1)+mean(can$CMIave1),logSA1=logSA*sd(can$logSA1)+mean(can$logSA1))] %>% 
  .[,":="(logSA=as.factor(round(logSA,2)),logSA1=as.factor(round(logSA1,2)))]
head(plot_df);nrow(plot_df)

seq(min(can$SA1),max(can$SA1),length=3);mean(can$SA1)
CMI_Mort_SA<-ggplot(plot_df,aes(y=mean,x=(CMIave1),color=logSA))+
  theme_classic()+
  geom_ribbon(aes(x=(CMIave1),ymin=low,ymax=up,
                  group=logSA),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1.1)+
  scale_colour_manual(values=c("maroon2","black","lightslateblue","dodgerblue4"),name="Stand age (yrs)",
                      labels=c("-6.45"="3", "-1.69"="189","3.07"="376","0"="Mean (86.29)"))+
  xlab("")+
  ylab(expression(paste("Mortality (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x= element_blank(), axis.line.y = element_line(),
        legend.title.align  = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour="black"))+
  ylim(0,4.5)
CMI_Mort_SA<-CMI_Mort_SA+annotate("text",x=150,y=4.1,label="ln(SA):~italic(P) <0.001",parse=TRUE,size=3.5)
CMI_Mort_SA<-CMI_Mort_SA+annotate("text",x=150,y=3.8,label="CMIave%*%ln(SA):~italic(P) <0.001",parse=TRUE,size=3.5)
CMI_Mort_SA

summary(mc)$co

#SA effect depends on MATave
coefmean<-summary(mc)$co[,1]
coefSE<-summary(mc)$co[,2]
plot_df<-expand.grid(MATave=can$MATave,logSA=round(c(seq(quantile(can$logSA,0.05)[[1]],quantile(can$logSA,0.95)[[1]],length=3),0),2)) %>%
  mutate(mean=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["MATave"]*MATave+
           coefmean["logSA:MATave"]*logSA*MATave) %>% 
  mutate(up=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["MATave"]*MATave+
           coefmean["logSA:MATave"]*logSA*MATave+
           coefSE["(Intercept)"]+coefSE["logSA"]*logSA+coefSE["MATave"]*MATave+
           coefSE["logSA:MATave"]*logSA*MATave) %>% 
  mutate(low=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["MATave"]*MATave+
           coefmean["logSA:MATave"]*logSA*MATave-
           (coefSE["(Intercept)"]+coefSE["logSA"]*logSA+coefSE["MATave"]*MATave+
              coefSE["logSA:MATave"]*logSA*MATave)) %>% 
  as.data.table()
plot_df[,":="(MATave1=MATave*sd(can$MATave1)+mean(can$MATave1),logSA1=logSA*sd(can$logSA1)+mean(can$logSA1))] %>% 
  .[,":="(logSA=as.factor(round(logSA,2)),logSA1=as.factor(round(logSA1,2)))]
head(plot_df);nrow(plot_df)

MAT_Mort_SA<-ggplot(plot_df,aes(y=mean,x=(MATave1),color=logSA))+
  theme_classic()+
  geom_ribbon(aes(x=(MATave1),ymin=low,ymax=up,
                  group=logSA),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1.1)+
  scale_colour_manual(values=c("violetred3","black","violet","turquoise"),name="",
                      labels=c("-6.45"="3", "-1.69"="189","3.07"="376","0"="Mean (86.29)"))+
  xlab("")+
  ylab(expression(paste("Mortality (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x= element_blank(), axis.line.y = element_line(),
        legend.title.align  = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour="black"))#+
#ylim(-0.05,5)
MAT_Mort_SA<-MAT_Mort_SA+annotate("text",x= 3,y=4.5,label="MATave%*%ln(SA):~italic(P) == 0.001",parse=TRUE,size=3.5)
MAT_Mort_SA

summary(mc)$co

## Net biomass change
#SA effects depends on CMIave
coefmean<-summary(ma)$co[,1]
coefSE<-summary(ma)$co[,2]
plot_df<-expand.grid(CMIave=can$CMIave,logSA=round(c(seq(quantile(can$logSA,0.05)[[1]],quantile(can$logSA,0.95)[[1]],length=3),0),2)) %>%
  mutate(mean=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["CMIave"]*CMIave+
           coefmean["logSA:CMIave"]*logSA*CMIave) %>% 
  mutate(up=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["CMIave"]*CMIave+
           coefmean["logSA:CMIave"]*logSA*CMIave+
           coefSE["(Intercept)"]+coefSE["logSA"]*logSA+coefSE["CMIave"]*CMIave+
           coefSE["logSA:CMIave"]*logSA*CMIave) %>% 
  mutate(low=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["CMIave"]*CMIave+
           coefmean["logSA:CMIave"]*logSA*CMIave-
           (coefSE["(Intercept)"]+coefSE["logSA"]*logSA+coefSE["CMIave"]*CMIave+
              coefSE["logSA:CMIave"]*logSA*CMIave)) %>% 
  as.data.table()
plot_df[,":="(CMIave1=CMIave*sd(can$CMIave1)+mean(can$CMIave1),logSA1=logSA*sd(can$logSA1)+mean(can$logSA1))] %>% 
  .[,":="(logSA=as.factor(round(logSA,2)),logSA1=as.factor(round(logSA1,2)))]
head(plot_df);nrow(plot_df)

CMI_NBC_SA<-ggplot(plot_df,aes(y=mean,x=(CMIave1),color=logSA))+
  theme_classic()+
  geom_ribbon(aes(x=(CMIave1),ymin=low,ymax=up,
                  group=logSA),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1.1)+
  scale_colour_manual(values=c("maroon2","black","lightslateblue","dodgerblue4"),name="",
                      labels=c("-0.83841231"="1.00","-0.4126802475"="2.12","0.013051815"="3.25",
                               "0.4387838775"="4.37","0.86451594"="5.31","0"="Mean"),
                      guide=guide_legend(override.aes = list(colour=NA,fill=NA)))+
  xlab(expression(paste(CMI[ave]," (cm)")))+
  ylab(expression(paste("Net biomass change (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.line.y = element_line(),
        legend.title.align = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))
CMI_NBC_SA<-CMI_NBC_SA+annotate("text",x=150,y=10,label="ln(SA):~italic(P) <0.001",parse=TRUE,size=3.5)
CMI_NBC_SA<-CMI_NBC_SA+annotate("text",x=150,y=8,label="CMIave%*%ln(SA):~italic(P) <0.001",parse=TRUE,size=3.5)
CMI_NBC_SA

summary(ma)$co

#SA effect depends on MATave
coefmean<-summary(ma)$co[,1]
coefSE<-summary(ma)$co[,2]
plot_df<-expand.grid(MATave=can$MATave,logSA=round(c(seq(quantile(can$logSA,0.05)[[1]],quantile(can$logSA,0.95)[[1]],length=3),0),2)) %>%
  mutate(mean=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["MATave"]*MATave+
           coefmean["logSA:MATave"]*logSA*MATave) %>% 
  mutate(up=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["MATave"]*MATave+
           coefmean["logSA:MATave"]*logSA*MATave+
           coefSE["(Intercept)"]+coefSE["logSA"]*logSA+coefSE["MATave"]*MATave+
           coefSE["logSA:MATave"]*logSA*MATave) %>% 
  mutate(low=coefmean["(Intercept)"]+coefmean["logSA"]*logSA+coefmean["MATave"]*MATave+
           coefmean["logSA:MATave"]*logSA*MATave-
           (coefSE["(Intercept)"]+coefSE["logSA"]*logSA+coefSE["MATave"]*MATave+
              coefSE["logSA:MATave"]*logSA*MATave)) %>% 
  as.data.table()
plot_df[,":="(MATave1=MATave*sd(can$MATave1)+mean(can$MATave1),logSA1=logSA*sd(can$logSA1)+mean(can$logSA1))] %>% 
  .[,":="(logSA=as.factor(round(logSA,2)),logSA1=as.factor(round(logSA1,2)))]
head(plot_df);nrow(plot_df)

MAT_NBC_SA<-ggplot(plot_df,aes(y=mean,x=(MATave1),color=logSA))+
  theme_classic()+
  geom_ribbon(aes(x=(MATave1),ymin=low,ymax=up,
                  group=logSA),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1.1)+
  scale_colour_manual(values=c("violetred3","black","violet","turquoise"),name="",
                      labels=c("-0.83841231"="1.00", "-0.4126802475"="2.12","0.013051815"="3.25",
                               "0.4387838775"="4.37","0.86451594"="5.31","0"="Mean"),
                      guide=guide_legend(override.aes = list(colour=NA,fill=NA)))+
  xlab(expression(paste(MAT[ave]," (",~degree*C,")")))+
  ylab(expression(paste("Net biomass change (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.line.y = element_line(),
        legend.title.align = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))
MAT_NBC_SA<-MAT_NBC_SA+annotate("text",x=3,y=8,label="MATave%*%ln(SA):~italic(P) <0.001",parse=TRUE,size=3.5)
MAT_NBC_SA

summary(ma)$co

dev.list() # s܂BŁARStudioGD̕\Ȃ΁A̃R[hsĂB
RStudioGD() #@łƂǂɂȂƂ܂B

#### Bind figures ####
rbind_gtable_max <- function(...){
  gtl <- list(...)
  stopifnot(all(sapply(gtl, is.gtable)))
  bind2 <- function (x, y) 
  {
    stopifnot(ncol(x) == ncol(y))
    if (nrow(x) == 0) 
      return(y)
    if (nrow(y) == 0) 
      return(x)
    y$layout$t <- y$layout$t + nrow(x)
    y$layout$b <- y$layout$b + nrow(x)
    x$layout <- rbind(x$layout, y$layout)
    x$heights <- gtable:::insert.unit(x$heights, y$heights)
    x$rownames <- c(x$rownames, y$rownames)
    x$widths <- grid::unit.pmax(x$widths, y$widths)
    x$grobs <- append(x$grobs, y$grobs)
    x
  }
  
  Reduce(bind2, gtl)
}

#SA bind
g1 <- ggplotGrob(CMI_Grow_SA)
g2 <- ggplotGrob(CMI_Mort_SA)
g3 <- ggplotGrob(CMI_NBC_SA)

h1 <- ggplotGrob(MAT_Grow_SA)
h2 <- ggplotGrob(MAT_Mort_SA)
h3 <- ggplotGrob(MAT_NBC_SA)

maxWidth = unit.pmax(g1$widths[2:3], g2$widths[2:3], g3$widths[2:3])
g1$widths[2:3] <- maxWidth
g2$widths[2:3] <- maxWidth
g3$widths[2:3] <- maxWidth

maxWidth = unit.pmax(h1$widths[2:3], h2$widths[2:3], h3$widths[2:3])
h1$widths[2:3] <- maxWidth
h2$widths[2:3] <- maxWidth
h3$widths[2:3] <- maxWidth

tiff("FigS_CMIave_MATave_effects_by_SA.tiff",width=2500,height=3000,res=300,compression="lzw")
grid.draw(cbind(rbind(g1,g2,g3,size="last"),rbind(h1,h2,h3,size="last"),size="first"))
grid.text("(a)",x=unit(0.02,"npc"),y=unit(0.993,"npc"),gp=gpar(fontsize=14,font=2))
grid.text("(b)",x=unit(0.52,"npc"),y=unit(0.993,"npc"),gp=gpar(fontsize=14,font=2))

dev.off()